# Research Questions:  

# Is the proportion of foreign-born residents associated with the rates of negative child outcomes (i.e., child maltreatment, child disability and low birth weight) at the county-level in the US? 
# Hypothesis: Counties with higher proportions of foreign-born residents have lower rates of negative child outcomes 

# Is the proportion of Latino residents associated with the rates of negative child outcomes at the county level in the US? 
# Hypothesis: Counties with higher proportions of Latino residents have lower rates of negative child outcomes 

# Is the ICE arrest rate associated with the rates of child outcomes?  
# Hypothesis: Counties with higher rates of ICE arrests have higher rates of negative child outcomes  

# Do these relationships differ by race/ethnicity?  
# Hypothesis: The associations between the proportion of foreign-born residents and the rates of negative child outcomes differ by racial/ethnic groups (i.e., Latino, Black, and White).  
# Hypothesis: The associations between the proportion of Latino residents and the rates of negative child outcomes differ by racial/ethnic groups (i.e., Latino, Black, and White).  
# Hypothesis: The associations between the rate of ICE arrests and the rates of negative child outcomes differ by racial/ethnic groups (i.e., Latino, Black, and White) 

# Do these relationships change by time?  
# Hypothesis: The associations between the proportion of foreign-born residents and the rates of negative child outcomes differ by time. 
# Hypothesis: The associations between the proportion of Latino residents and the rates of negative child outcomes differ by time. 
# Hypothesis: The associations between the rate of ICE arrests and the rates of negative child outcomes differ by time. 

# Loading libraries
library(lme4)       # for lmer
library(lmerTest)   # to get p-value from lmer
library(robustlmm)  # for robust estimation of lmer handling outliers
library(data.table) # to read data
library(bit64)      # to read data
library(e1071)      # for "skewness"
library(performance)# for "vif" for lmer fit



# Loading data
a<-fread('Z:/ICE_CM/ICE.csv' ,header=T,sep=',') # 2556 obs

# Categorizing variables
a$Year   <-as.factor(a$Year   )
a$USDA_RUC<-as.factor(a$USDA_RUC)


# Managing variables
a$HValueT<-a$HValueT/10000 # Owner occupied housing units Median value per $10k (in 2018 inflation-adjusted dollars),Total
a$IncomeT2<-a$IncomeT/1000 # Median Household Income per $1k (in 2018 inflation-adjusted dollars),Total
a$IncomeW2<-a$IncomeT/1000 # Median Household Income per $1k (in 2018 inflation-adjusted dollars),Total
a$IncomeB2<-a$IncomeT/1000 # Median Household Income per $1k (in 2018 inflation-adjusted dollars),Total
a$IncomeH2<-a$IncomeT/1000 # Median Household Income per $1k (in 2018 inflation-adjusted dollars),Total
a$DisablTC<-a$DisablTC*10 # Total Child disability rate per 1,000 children
a$DisablWC<-a$DisablWC*10 # White Child disability rate per 1,000 children
a$DisablBC<-a$DisablBC*10 # Black Child disability rate per 1,000 children
a$DisablHC<-a$DisablHC*10 # Latino Child disability rate per 1,000 children

# Creating outcome-specific data
CT0<-a # 2556 obs
CW0<-a # 2556 obs
CB0<-a # 2556 obs
CH0<-a # 2556 obs
DT0<-a # 2556 obs
DW0<-a # 2556 obs
DB0<-a # 2556 obs
DH0<-a # 2556 obs
LT0<-a # 2556 obs
LW0<-a # 2556 obs
LB0<-a # 2556 obs
LH0<-a # 2556 obs
PT0<-a # 2556 obs
PW0<-a # 2556 obs
PB0<-a # 2556 obs
PH0<-a # 2556 obs
TT0<-a # 2556 obs
TW0<-a # 2556 obs
TB0<-a # 2556 obs
TH0<-a # 2556 obs

# Birth data have no race-specific records prior to 2016
# Excluding 2015 data from race/ethnicity-specific birth data

LW0<-LW0[Year!="2015",] # 2556 obs -> 1917 obs
LB0<-LB0[Year!="2015",] # 2556 obs -> 1917 obs
LH0<-LH0[Year!="2015",] # 2556 obs -> 1917 obs
PW0<-PW0[Year!="2015",] # 2556 obs -> 1917 obs
PB0<-PB0[Year!="2015",] # 2556 obs -> 1917 obs
PH0<-PH0[Year!="2015",] # 2556 obs -> 1917 obs
TW0<-TW0[Year!="2015",] # 2556 obs -> 1917 obs
TB0<-TB0[Year!="2015",] # 2556 obs -> 1917 obs
TH0<-TH0[Year!="2015",] # 2556 obs -> 1917 obs

# Exclude Low Populated Counties
CT1<-CT0[CPopT>=300,] # 2556 obs -> 2556 obs
CW1<-CW0[CPopW>=300,] # 2556 obs -> 2556 obs
CB1<-CB0[CPopB>=300,] # 2556 obs -> 2352 obs
CH1<-CH0[CPopH>=300,] # 2556 obs -> 2535 obs
DT1<-DT0[CPopT>=300,] # 2556 obs -> 2556 obs
DW1<-DW0[CPopW>=300,] # 2556 obs -> 2556 obs
DB1<-DB0[CPopB>=300,] # 2556 obs -> 2352 obs
DH1<-DH0[CPopH>=300,] # 2556 obs -> 2535 obs
LT1<-LT0[CPopT>=300,] # 2556 obs -> 2556 obs
LW1<-LW0[CPopW>=300,] # 1917 obs -> 1917 obs
LB1<-LB0[CPopB>=300,] # 1917 obs -> 1765 obs
LH1<-LH0[CPopH>=300,] # 1917 obs -> 1903 obs
PT1<-PT0[CPopT>=300,] # 2556 obs -> 2556 obs
PW1<-PW0[CPopW>=300,] # 1917 obs -> 1917 obs
PB1<-PB0[CPopB>=300,] # 1917 obs -> 1765 obs
PH1<-PH0[CPopH>=300,] # 1917 obs -> 1903 obs
TT1<-TT0[CPopT>=300,] # 2556 obs -> 2556 obs
TW1<-TW0[CPopW>=300,] # 1917 obs -> 1917 obs
TB1<-TB0[CPopB>=300,] # 1917 obs -> 1765 obs
TH1<-TH0[CPopH>=300,] # 1917 obs -> 1903 obs

# Exclude Counties with missing values for the outcome
CT2<-CT1[!is.na(CT1$RptTr   ),] # 2556 obs -> 2556 obs
CW2<-CW1[!is.na(CW1$RptWr   ),] # 2556 obs -> 2556 obs
CB2<-CB1[!is.na(CB1$RptBr   ),] # 2352 obs -> 2352 obs
CH2<-CH1[!is.na(CH1$RptHr   ),] # 2535 obs -> 2535 obs
DT2<-DT1[!is.na(DT1$DisablTC),] # 2556 obs -> 2556 obs
DW2<-DW1[!is.na(DW1$DisablWC),] # 2556 obs -> 2556 obs
DB2<-DB1[!is.na(DB1$DisablBC),] # 2352 obs -> 2352 obs
DH2<-DH1[!is.na(DH1$DisablHC),] # 2535 obs -> 2535 obs
LT2<-LT1[!is.na(LT1$LBWT1r  ),] # 2556 obs -> 2044 obs
LW2<-LW1[!is.na(LW1$LBWW1r  ),] # 1917 obs -> 1528 obs
LB2<-LB1[!is.na(LB1$LBWB1r  ),] # 1765 obs -> 1218 obs
LH2<-LH1[!is.na(LH1$LBWH1r  ),] # 1903 obs -> 1256 obs
PT2<-PT1[!is.na(PT1$PTBT1r  ),] # 2556 obs -> 2044 obs
PW2<-PW1[!is.na(PW1$PTBW1r  ),] # 1917 obs -> 1530 obs
PB2<-PB1[!is.na(PB1$PTBB1r  ),] # 1765 obs -> 1230 obs
PH2<-PH1[!is.na(PH1$PTBH1r  ),] # 1903 obs -> 1329 obs
TT2<-TT1[!is.na(TT1$TBTT1r  ),] # 2556 obs -> 2044 obs
TW2<-TW1[!is.na(TW1$TBTW1r  ),] # 1917 obs -> 1494 obs
TB2<-TB1[!is.na(TB1$TBTB1r  ),] # 1765 obs -> 1073 obs
TH2<-TH1[!is.na(TH1$TBTH1r  ),] # 1903 obs -> 1260 obs

# Exclude counties with very extereme outcome values (outside +- 4.5 IQR)
CT3<-CT2[CT2$RptTr   <min(boxplot.stats(CT2$RptTr   ,coef=4.5)$out),] # 2556 obs -> 2556 obs
CW3<-CW2[CW2$RptWr   <min(boxplot.stats(CW2$RptWr   ,coef=4.5)$out),] # 2556 obs -> 2556 obs
CB3<-CB2[CB2$RptBr   <min(boxplot.stats(CB2$RptBr   ,coef=4.5)$out),] # 2352 obs -> 2344 obs
CH3<-CH2[CH2$RptHr   <min(boxplot.stats(CH2$RptHr   ,coef=4.5)$out),] # 2535 obs -> 2522 obs
DT3<-DT2[DT2$DisablTC<min(boxplot.stats(DT2$DisablTC,coef=4.5)$out),] # 2556 obs -> 2556 obs
DW3<-DW2[DW2$DisablWC<min(boxplot.stats(DW2$DisablWC,coef=4.5)$out),] # 2556 obs -> 2554 obs
DB3<-DB2[DB2$DisablBC<min(boxplot.stats(DB2$DisablBC,coef=4.5)$out),] # 2352 obs -> 2332 obs
DH3<-DH2[DH2$DisablHC<min(boxplot.stats(DH2$DisablHC,coef=4.5)$out),] # 2535 obs -> 2527 obs
LT3<-LT2[LT2$LBWT1r  <min(boxplot.stats(LT2$LBWT1r  ,coef=4.5)$out),] # 2044 obs -> 2044 obs
LW3<-LW2[LW2$LBWW1r  <min(boxplot.stats(LW2$LBWW1r  ,coef=4.5)$out),] # 1528 obs -> 1528 obs
LB3<-LB2[LB2$LBWB1r  <min(boxplot.stats(LB2$LBWB1r  ,coef=4.5)$out),] # 1218 obs -> 1217 obs
LH3<-LH2[LH2$LBWH1r  <min(boxplot.stats(LH2$LBWH1r  ,coef=4.5)$out),] # 1256 obs -> 1255 obs
PT3<-PT2[PT2$PTBT1r  <min(boxplot.stats(PT2$PTBT1r  ,coef=4.5)$out),] # 2044 obs -> 2044 obs
PW3<-PW2[PW2$PTBW1r  <min(boxplot.stats(PW2$PTBW1r  ,coef=4.5)$out),] # 1530 obs -> 1530 obs
PB3<-PB2[PB2$PTBB1r  <min(boxplot.stats(PB2$PTBB1r  ,coef=4.5)$out),] # 1230 obs -> 1229 obs
PH3<-PH2[PH2$PTBH1r  <min(boxplot.stats(PH2$PTBH1r  ,coef=4.5)$out),] # 1329 obs -> 1327 obs
TT3<-TT2[TT2$TBTT1r  <min(boxplot.stats(TT2$TBTT1r  ,coef=4.5)$out),] # 2044 obs -> 2044 obs
TW3<-TW2[TW2$TBTW1r  <min(boxplot.stats(TW2$TBTW1r  ,coef=4.5)$out),] # 1494 obs -> 1494 obs
TB3<-TB2[TB2$TBTB1r  <min(boxplot.stats(TB2$TBTB1r  ,coef=4.5)$out),] # 1073 obs -> 1068 obs
TH3<-TH2[TH2$TBTH1r  <min(boxplot.stats(TH2$TBTH1r  ,coef=4.5)$out),] # 1260 obs -> 1257 obs

# County Coverage
nrow(CT3)/nrow(CT0)
nrow(CW3)/nrow(CW0)
nrow(CB3)/nrow(CB0)
nrow(CH3)/nrow(CH0)
nrow(DT3)/nrow(DT0)
nrow(DW3)/nrow(DW0)
nrow(DB3)/nrow(DB0)
nrow(DH3)/nrow(DH0)
nrow(LT3)/nrow(LT0)
nrow(LW3)/nrow(LW0)
nrow(LB3)/nrow(LB0)
nrow(LH3)/nrow(LH0)
nrow(PT3)/nrow(PT0)
nrow(PW3)/nrow(PW0)
nrow(PB3)/nrow(PB0)
nrow(PH3)/nrow(PH0)
nrow(TT3)/nrow(TT0)
nrow(TW3)/nrow(TW0)
nrow(TB3)/nrow(TB0)
nrow(TH3)/nrow(TH0)

# Child Population Coverage
sum(CT3$CPopT)/sum(CT0$CPopT)
sum(CW3$CPopW)/sum(CW0$CPopW)
sum(CB3$CPopB)/sum(CB0$CPopB)
sum(CH3$CPopH)/sum(CH0$CPopH)
sum(DT3$CPopT)/sum(DT0$CPopT)
sum(DW3$CPopW)/sum(DW0$CPopW)
sum(DB3$CPopB)/sum(DB0$CPopB)
sum(DH3$CPopH)/sum(DH0$CPopH)
sum(LT3$CPopT)/sum(LT0$CPopT)
sum(LW3$CPopW)/sum(LW0$CPopW)
sum(LB3$CPopB)/sum(LB0$CPopB)
sum(LH3$CPopH)/sum(LH0$CPopH)
sum(PT3$CPopT)/sum(PT0$CPopT)
sum(PW3$CPopW)/sum(PW0$CPopW)
sum(PB3$CPopB)/sum(PB0$CPopB)
sum(PH3$CPopH)/sum(PH0$CPopH)
sum(TT3$CPopT)/sum(TT0$CPopT)
sum(TW3$CPopW)/sum(TW0$CPopW)
sum(TB3$CPopB)/sum(TB0$CPopB)
sum(TH3$CPopH)/sum(TH0$CPopH)

# Distributions: boxplot
boxplot(CT2$RptTr,CW2$RptWr,CB2$RptBr,CH2$RptHr)
boxplot(CT3$RptTr,CW3$RptWr,CB3$RptBr,CH3$RptHr)
boxplot(DT2$DisablTC,DW2$DisablWC,DB2$DisablBC,DH2$DisablHC)
boxplot(DT3$DisablTC,DW3$DisablWC,DB3$DisablBC,DH3$DisablHC)
boxplot(LT2$LBWT1r,LW2$LBWW1r,LB2$LBWB1r,LH2$LBWH1r)
boxplot(LT3$LBWT1r,LW3$LBWW1r,LB3$LBWB1r,LH3$LBWH1r)
boxplot(PT2$PTBT1r,PW2$PTBW1r,PB2$PTBB1r,PH2$PTBH1r)
boxplot(PT3$PTBT1r,PW3$PTBW1r,PB3$PTBB1r,PH3$PTBH1r)
boxplot(TT2$TBTT1r,TW2$TBTW1r,TB2$TBTB1r,TH2$TBTH1r)
boxplot(TT3$TBTT1r,TW3$TBTW1r,TB3$TBTB1r,TH3$TBTH1r)

# Distributions: skewness
skewness(CT3$RptTr   )
skewness(CW3$RptWr   )
skewness(CB3$RptBr   )
skewness(CH3$RptHr   )
skewness(DT3$DisablTC)
skewness(DW3$DisablWC)
skewness(DB3$DisablBC)
skewness(DH3$DisablHC)
skewness(LT3$LBWT1r  )
skewness(LW3$LBWW1r  )
skewness(LB3$LBWB1r  )
skewness(LH3$LBWH1r  )
skewness(PT3$PTBT1r  )
skewness(PW3$PTBW1r  )
skewness(PB3$PTBB1r  )
skewness(PH3$PTBH1r  )
skewness(TT3$TBTT1r  )
skewness(TW3$TBTW1r  )
skewness(TB3$TBTB1r  )
skewness(TH3$TBTH1r  )

# Distributions: density plot
plot(density(CT3$RptTr   ))
plot(density(CW3$RptWr   ))
plot(density(CB3$RptBr   ))
plot(density(CH3$RptHr   ))
plot(density(DT3$DisablTC))
plot(density(DW3$DisablWC))
plot(density(DB3$DisablBC))
plot(density(DH3$DisablHC))
plot(density(LT3$LBWT1r  ))
plot(density(LW3$LBWW1r  ))
plot(density(LB3$LBWB1r  ))
plot(density(LH3$LBWH1r  ))
plot(density(PT3$PTBT1r  ))
plot(density(PW3$PTBW1r  ))
plot(density(PB3$PTBB1r  ))
plot(density(PH3$PTBH1r  ))
plot(density(TT3$TBTT1r  ))
plot(density(TW3$TBTW1r  ))
plot(density(TB3$TBTB1r  ))
plot(density(TH3$TBTH1r  ))

# Renaming datasets
CT<-CT3
CW<-CW3
CB<-CB3
CH<-CH3
DT<-DT3
DW<-DW3
DB<-DB3
DH<-DH3
LT<-LT3
LW<-LW3
LB<-LB3
LH<-LH3
PT<-PT3
PW<-PW3
PB<-PB3
PH<-PH3
TT<-TT3
TW<-TW3
TB<-TB3
TH<-TH3

rm(list= ls()[!(ls() %in% c("CT","CW","CB","CH","CN","CP","CS","DT","DW","DB","DH","IA","LT","LW","LB","LH","TT","TW","TB","TH","PT","PW","PB","PH"))])

# Descriptive Statistics
# DVs  
Table1<-data.table(mean=c(mean(CT$RptTr),mean(CW$RptWr),mean(CB$RptBr),mean(CH$RptHr),mean(DT$DisablTC),mean(DW$DisablWC),mean(DB$DisablBC),mean(DH$DisablHC),mean(CT$FBornT),mean(CT$PopHP),mean(CT$ICEArrYCR),mean(CT$PopBP),mean(CT$ChildPT),mean(CT$ChildPW),mean(CT$ChildPB),mean(CT$ChildPH),mean(CT$MalePT),mean(CT$MalePW),mean(CT$MalePB),mean(CT$MalePH),mean(CT$SingleT),mean(CT$SingleW),mean(CT$SingleB),mean(CT$SingleH),mean(CT$NoHighT),mean(CT$NoHighW),mean(CT$NoHighB),mean(CT$NoHighH),mean(CT$CPovT),mean(CT$CPovW),mean(CT$CPovB),mean(CT$CPovH),mean(CT$HValueT),mean(CT$HInsurTC),mean(CT$HInsurWC),mean(CT$HInsurBC),mean(CT$HInsurHC),mean(CT$MoveT),mean(CT$MoveW),mean(CT$MoveB),mean(CT$MoveH),prop.table(table(CT$USDA_RUC))),
                   SD=c(sd(CT$RptTr),sd(CW$RptWr),sd(CB$RptBr),sd(CH$RptHr),sd(DT$DisablTC),sd(DW$DisablWC),sd(DB$DisablBC),sd(DH$DisablHC),sd(CT$FBornT),sd(CT$PopHP),sd(CT$ICEArrYCR),sd(CT$PopBP),sd(CT$ChildPT),sd(CT$ChildPW),sd(CT$ChildPB),sd(CT$ChildPH),sd(CT$MalePT),sd(CT$MalePW),sd(CT$MalePB),sd(CT$MalePH),sd(CT$SingleT),sd(CT$SingleW),sd(CT$SingleB),sd(CT$SingleH),sd(CT$NoHighT),sd(CT$NoHighW),sd(CT$NoHighB),sd(CT$NoHighH),sd(CT$CPovT),sd(CT$CPovW),sd(CT$CPovB),sd(CT$CPovH),sd(CT$HValueT),sd(CT$HInsurTC),sd(CT$HInsurWC),sd(CT$HInsurBC),sd(CT$HInsurHC),sd(CT$MoveT),sd(CT$MoveW),sd(CT$MoveB),sd(CT$MoveH),NA,NA,NA))
Table1
write.csv(Table1,"Z:/ICE_CM/Tables/Table1.csv")






# Child Maltreatment Report  
# Child Maltreatment Report  
# Child Maltreatment Report  
# Child Maltreatment Report  
# Child Maltreatment Report  
  
# Centering Variables
mean(CT$PopHP)     
mean(CT$FBornT)    
mean(CT$ICEArrR)   
mean(CT$ICEArrYCR) 
mean(CW$PopHP)     
mean(CW$FBornT)    
mean(CW$ICEArrR)   
mean(CW$ICEArrYCR) 
mean(CB$PopHP)     
mean(CB$FBornT)    
mean(CB$ICEArrR)   
mean(CB$ICEArrYCR) 
mean(CH$PopHP)     
mean(CH$FBornT)    
mean(CH$ICEArrR)   
mean(CH$ICEArrYCR) 

CT$PopHPc    <-CT$PopHP    -mean(CT$PopHP)
CT$FBornTc   <-CT$FBornT   -mean(CT$FBornT)
CT$ICEArrRc  <-CT$ICEArrR  -mean(CT$ICEArrR)
CT$ICEArrYCRc<-CT$ICEArrYCR-mean(CT$ICEArrYCR)
CW$PopHPc    <-CW$PopHP    -mean(CW$PopHP)
CW$FBornTc   <-CW$FBornT   -mean(CW$FBornT)
CW$ICEArrRc  <-CW$ICEArrR  -mean(CW$ICEArrR)
CW$ICEArrYCRc<-CW$ICEArrYCR-mean(CW$ICEArrYCR)
CB$PopHPc    <-CB$PopHP    -mean(CB$PopHP)
CB$FBornTc   <-CB$FBornT   -mean(CB$FBornT)
CB$ICEArrRc  <-CB$ICEArrR  -mean(CB$ICEArrR)
CB$ICEArrYCRc<-CB$ICEArrYCR-mean(CB$ICEArrYCR)
CH$PopHPc    <-CH$PopHP    -mean(CH$PopHP)
CH$FBornTc   <-CH$FBornT   -mean(CH$FBornT)
CH$ICEArrRc  <-CH$ICEArrR  -mean(CH$ICEArrR)
CH$ICEArrYCRc<-CH$ICEArrYCR-mean(CH$ICEArrYCR)

CT$RUC2<-0;CT$RUC2[CT$USDA_RUC=="2"]<-1;CT$RUC3<-0;CT$RUC3[CT$USDA_RUC=="3"]<-1
CW$RUC2<-0;CW$RUC2[CW$USDA_RUC=="2"]<-1;CW$RUC3<-0;CW$RUC3[CW$USDA_RUC=="3"]<-1
CB$RUC2<-0;CB$RUC2[CB$USDA_RUC=="2"]<-1;CB$RUC3<-0;CB$RUC3[CB$USDA_RUC=="3"]<-1
CH$RUC2<-0;CH$RUC2[CH$USDA_RUC=="2"]<-1;CH$RUC3<-0;CH$RUC3[CH$USDA_RUC=="3"]<-1

CT$Y2016<-0;CT$Y2016[CT$Year=="2016"]<-1
CT$Y2017<-0;CT$Y2017[CT$Year=="2017"]<-1
CT$Y2018<-0;CT$Y2018[CT$Year=="2018"]<-1
CW$Y2016<-0;CW$Y2016[CW$Year=="2016"]<-1
CW$Y2017<-0;CW$Y2017[CW$Year=="2017"]<-1
CW$Y2018<-0;CW$Y2018[CW$Year=="2018"]<-1
CB$Y2016<-0;CB$Y2016[CB$Year=="2016"]<-1
CB$Y2017<-0;CB$Y2017[CB$Year=="2017"]<-1
CB$Y2018<-0;CB$Y2018[CB$Year=="2018"]<-1
CH$Y2016<-0;CH$Y2016[CH$Year=="2016"]<-1
CH$Y2017<-0;CH$Y2017[CH$Year=="2017"]<-1
CH$Y2018<-0;CH$Y2018[CH$Year=="2018"]<-1

# Modeling
CTm0 <-lmer(RptTr~Y2016+Y2017+Y2018                                                                                                     +(1|CountyFIPS)+(1|StateFIPS),data=CT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CTm1 <-lmer(RptTr~Y2016+Y2017+Y2018+PopHPc                                                                                              +(1|CountyFIPS)+(1|StateFIPS),data=CT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CTm2 <-lmer(RptTr~Y2016+Y2017+Y2018+FBornTc                                                                                             +(1|CountyFIPS)+(1|StateFIPS),data=CT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CTm4 <-lmer(RptTr~Y2016+Y2017+Y2018+ICEArrYCRc                                                                                          +(1|CountyFIPS)+(1|StateFIPS),data=CT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CTm5 <-lmer(RptTr~Y2016+Y2017+Y2018+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+RUC2+RUC3+HInsurTC+(1|CountyFIPS)+(1|StateFIPS),data=CT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CTm6 <-lmer(RptTr~Y2016+Y2017+Y2018+Y2016*PopHPc+Y2017*PopHPc+Y2018*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+RUC2+RUC3+HInsurTC+(1|CountyFIPS)+(1|StateFIPS),data=CT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CTm7 <-lmer(RptTr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+RUC2+RUC3+HInsurTC+(1|CountyFIPS)+(1|StateFIPS),data=CT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CTm8 <-lmer(RptTr~Y2016+Y2017+Y2018+Y2016*ICEArrYCRc+Y2017*ICEArrYCRc+Y2018*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+RUC2+RUC3+HInsurTC+(1|CountyFIPS)+(1|StateFIPS),data=CT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CTm9 <-lmer(RptTr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+Y2016*PopHPc+Y2017*PopHPc+Y2018*PopHPc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+RUC2+RUC3+HInsurTC+(1|CountyFIPS)+(1|StateFIPS),data=CT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CTm10<-lmer(RptTr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+PopHPc+Y2016*ICEArrYCRc+Y2017*ICEArrYCRc+Y2018*ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+RUC2+RUC3+HInsurTC+(1|CountyFIPS)+(1|StateFIPS),data=CT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CWm0 <-lmer(RptWr~Y2016+Y2017+Y2018                                                                                                     +(1|CountyFIPS)+(1|StateFIPS),data=CW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CWm1 <-lmer(RptWr~Y2016+Y2017+Y2018+PopHPc                                                                                              +(1|CountyFIPS)+(1|StateFIPS),data=CW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CWm2 <-lmer(RptWr~Y2016+Y2017+Y2018+FBornTc                                                                                             +(1|CountyFIPS)+(1|StateFIPS),data=CW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CWm4 <-lmer(RptWr~Y2016+Y2017+Y2018+ICEArrYCRc                                                                                          +(1|CountyFIPS)+(1|StateFIPS),data=CW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CWm5 <-lmer(RptWr~Y2016+Y2017+Y2018+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+HInsurWC+MoveW+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CWm6 <-lmer(RptWr~Y2016+Y2017+Y2018+Y2016*PopHPc+Y2017*PopHPc+Y2018*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+HInsurWC+MoveW+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CWm7 <-lmer(RptWr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+HInsurWC+MoveW+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CWm8 <-lmer(RptWr~Y2016+Y2017+Y2018+Y2016*ICEArrYCRc+Y2017*ICEArrYCRc+Y2018*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+HInsurWC+MoveW+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CWm9 <-lmer(RptWr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+Y2016*PopHPc+Y2017*PopHPc+Y2018*PopHPc+ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+HInsurWC+MoveW+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CWm10<-lmer(RptWr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+PopHPc+Y2016*ICEArrYCRc+Y2017*ICEArrYCRc+Y2018*ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+HInsurWC+MoveW+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CBm0 <-lmer(RptBr~Y2016+Y2017+Y2018                                                                                                     +(1|CountyFIPS)+(1|StateFIPS),data=CB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CBm1 <-lmer(RptBr~Y2016+Y2017+Y2018+PopHPc                                                                                              +(1|CountyFIPS)+(1|StateFIPS),data=CB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CBm2 <-lmer(RptBr~Y2016+Y2017+Y2018+FBornTc                                                                                             +(1|CountyFIPS)+(1|StateFIPS),data=CB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CBm4 <-lmer(RptBr~Y2016+Y2017+Y2018+ICEArrYCRc                                                                                          +(1|CountyFIPS)+(1|StateFIPS),data=CB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CBm5 <-lmer(RptBr~Y2016+Y2017+Y2018+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+HInsurBC+MoveB+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CBm6 <-lmer(RptBr~Y2016+Y2017+Y2018+Y2016*PopHPc+Y2017*PopHPc+Y2018*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+HInsurBC+MoveB+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CBm7 <-lmer(RptBr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+HInsurBC+MoveB+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CBm8 <-lmer(RptBr~Y2016+Y2017+Y2018+Y2016*ICEArrYCRc+Y2017*ICEArrYCRc+Y2018*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+HInsurBC+MoveB+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CBm9 <-lmer(RptBr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+Y2016*PopHPc+Y2017*PopHPc+Y2018*PopHPc+ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+HInsurBC+MoveB+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CBm10<-lmer(RptBr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+PopHPc+Y2016*ICEArrYCRc+Y2017*ICEArrYCRc+Y2018*ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+HInsurBC+MoveB+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CHm0 <-lmer(RptHr~Y2016+Y2017+Y2018                                                                                                     +(1|CountyFIPS)+(1|StateFIPS),data=CH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CHm1 <-lmer(RptHr~Y2016+Y2017+Y2018+PopHPc                                                                                              +(1|CountyFIPS)+(1|StateFIPS),data=CH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CHm2 <-lmer(RptHr~Y2016+Y2017+Y2018+FBornTc                                                                                             +(1|CountyFIPS)+(1|StateFIPS),data=CH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CHm4 <-lmer(RptHr~Y2016+Y2017+Y2018+ICEArrYCRc                                                                                          +(1|CountyFIPS)+(1|StateFIPS),data=CH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CHm5 <-lmer(RptHr~Y2016+Y2017+Y2018+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+HInsurHC+MoveH+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CHm6 <-lmer(RptHr~Y2016+Y2017+Y2018+Y2016*PopHPc+Y2017*PopHPc+Y2018*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+HInsurHC+MoveH+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CHm7 <-lmer(RptHr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+HInsurHC+MoveH+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CHm8 <-lmer(RptHr~Y2016+Y2017+Y2018+Y2016*ICEArrYCRc+Y2017*ICEArrYCRc+Y2018*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+HInsurHC+MoveH+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CHm9 <-lmer(RptHr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+Y2016*PopHPc+Y2017*PopHPc+Y2018*PopHPc+ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+HInsurHC+MoveH+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
CHm10<-lmer(RptHr~Y2016+Y2017+Y2018+Y2016*FBornTc+Y2017*FBornTc+Y2018*FBornTc+PopHPc+Y2016*ICEArrYCRc+Y2017*ICEArrYCRc+Y2018*ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+HInsurHC+MoveH+RUC2+RUC3+(1|CountyFIPS)+(1|StateFIPS),data=CH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

# Formal Test for Interaction
anova(CTm1,CTm1x,CTm4x)
anova(CTm2,CTm2x)
anova(CTm4,CTm4x)
summary(CTm1x)
summary(CTm2x)
summary(CTm4x)

anova(CWm1,CWm1x)
anova(CWm2,CWm2x)
anova(CWm4,CWm4x)
summary(CWm1x)
summary(CWm2x)
summary(CWm4x)

anova(CBm1,CBm1x)
anova(CBm2,CBm2x)
anova(CBm4,CBm4x)
summary(CBm1x)
summary(CBm2x)
summary(CBm4x)

anova(CHm1,CHm1x)
anova(CHm2,CHm2x)
anova(CHm4,CHm4x)
summary(CHm1x)
summary(CHm2x)
summary(CHm4x)


anova(CTm5a,CTm7a,CTm9a)
anova(CTm5a,CTm7a,CTm10a)
anova(CTm5a,CTm8a)
summary(CTm5a)
summary(CTm6a)
summary(CTm7a) #
summary(CTm8a)
summary(CTm9a)

anova(CWm5a,CWm6a,CWm9a)
anova(CWm5a,CWm7a,CWm9a)
anova(CWm5a,CWm8a )
summary(CWm5a)
summary(CWm6a)
summary(CWm7a) #
summary(CWm8a)
summary(CWm9a)

anova(CBm5a,CBm6a,CBm9a)
anova(CBm5a,CBm7a,CBm9a)
anova(CBm5a,CBm8a )
summary(CBm5a)
summary(CBm6a)
summary(CBm7a) #
summary(CBm8a)
summary(CBm9a)

anova(CHm5a,CHm6a,CHm9a )
anova(CHm5a,CHm7a,CHm9a )
anova(CHm5a,CHm8a )
summary(CHm5a)
summary(CHm6a)
summary(CHm7a) #
summary(CHm8a)
summary(CHm9a)

# bootstrap confidence interval
CTm7CI<-confint(CTm7,method='boot',nsim=1000,boot.type='perc')
CWm7CI<-confint(CWm7,method='boot',nsim=1000,boot.type='perc')
CBm7CI<-confint(CBm7,method='boot',nsim=1000,boot.type='perc')
CHm7CI<-confint(CHm7,method='boot',nsim=1000,boot.type='perc')

# Prediction Graphs and Bootstrap Confidence Intervals
# Prediction Graphs and Bootstrap Confidence Intervals
# Prediction Graphs and Bootstrap Confidence Intervals
# Prediction Graphs and Bootstrap Confidence Intervals
# Prediction Graphs and Bootstrap Confidence Intervals
# Prediction Graphs and Bootstrap Confidence Intervals

# Create model matrix of IV values for prediction
# Total
round(quantile(CT$FBornT,c(0.025,0.975)))
CTpd<-data.frame(FBornT=seq(0,30,by=1))
CTpd$FBornTc   <-CTpd$FBornT-mean(CT$FBornT)
CTpd$PopHPc    <-mean(CT$PopHPc    )
CTpd$ICEArrYCRc<-mean(CT$ICEArrYCRc)
CTpd$PopBP     <-mean(CT$PopBP     )
CTpd$ChildPT   <-mean(CT$ChildPT   )
CTpd$MalePT    <-mean(CT$MalePT    )
CTpd$SingleT   <-mean(CT$SingleT   )
CTpd$NoHighT   <-mean(CT$NoHighT   )
CTpd$CPovT     <-mean(CT$CPovT     )
CTpd$HValueT   <-mean(CT$HValueT   )
CTpd$MoveT     <-mean(CT$MoveT     )
CTpd$RUC2      <-mean(CT$RUC2      )
CTpd$RUC3      <-mean(CT$RUC3      )
CTpd$HInsurTC  <-mean(CT$HInsurTC  )
CTpd15<-CTpd;CTpd15$Y2016<-0;CTpd15$Y2017<-0;CTpd15$Y2018<-0
CTpd16<-CTpd;CTpd16$Y2016<-1;CTpd16$Y2017<-0;CTpd16$Y2018<-0
CTpd17<-CTpd;CTpd17$Y2016<-0;CTpd17$Y2017<-1;CTpd17$Y2018<-0
CTpd18<-CTpd;CTpd18$Y2016<-0;CTpd18$Y2017<-0;CTpd18$Y2018<-1
CTpd15$"Y2016:FBornTc"<-0*CTpd15$FBornTc
CTpd15$"Y2017:FBornTc"<-0*CTpd15$FBornTc
CTpd15$"Y2018:FBornTc"<-0*CTpd15$FBornTc
CTpd16$"Y2016:FBornTc"<-1*CTpd16$FBornTc
CTpd16$"Y2017:FBornTc"<-0*CTpd16$FBornTc
CTpd16$"Y2018:FBornTc"<-0*CTpd16$FBornTc
CTpd17$"Y2016:FBornTc"<-0*CTpd17$FBornTc
CTpd17$"Y2017:FBornTc"<-1*CTpd17$FBornTc
CTpd17$"Y2018:FBornTc"<-0*CTpd17$FBornTc
CTpd18$"Y2016:FBornTc"<-0*CTpd18$FBornTc
CTpd18$"Y2017:FBornTc"<-0*CTpd18$FBornTc
CTpd18$"Y2018:FBornTc"<-1*CTpd18$FBornTc

round(quantile(CW$FBornT,c(0.025,0.975)))
CWpd<-data.frame(FBornT=seq(0,30,by=1))
CWpd$FBornTc   <-CWpd$FBornT-mean(CW$FBornT)
CWpd$PopHPc    <-mean(CW$PopHPc    )
CWpd$ICEArrYCRc<-mean(CW$ICEArrYCRc)
CWpd$PopBP     <-mean(CW$PopBP     )
CWpd$ChildPW   <-mean(CW$ChildPW   )
CWpd$MalePW    <-mean(CW$MalePW    )
CWpd$SingleW   <-mean(CW$SingleW   )
CWpd$NoHighW   <-mean(CW$NoHighW   )
CWpd$CPovW     <-mean(CW$CPovW     )
CWpd$HValueT   <-mean(CW$HValueT   )
CWpd$HInsurWC  <-mean(CW$HInsurWC  )
CWpd$MoveW     <-mean(CW$MoveW     )
CWpd$RUC2      <-mean(CW$RUC2      )
CWpd$RUC3      <-mean(CW$RUC3      )
CWpd15<-CWpd;CWpd15$Y2016<-0;CWpd15$Y2017<-0;CWpd15$Y2018<-0
CWpd16<-CWpd;CWpd16$Y2016<-1;CWpd16$Y2017<-0;CWpd16$Y2018<-0
CWpd17<-CWpd;CWpd17$Y2016<-0;CWpd17$Y2017<-1;CWpd17$Y2018<-0
CWpd18<-CWpd;CWpd18$Y2016<-0;CWpd18$Y2017<-0;CWpd18$Y2018<-1
CWpd15$"Y2016:FBornTc"<-0*CWpd15$FBornTc
CWpd15$"Y2017:FBornTc"<-0*CWpd15$FBornTc
CWpd15$"Y2018:FBornTc"<-0*CWpd15$FBornTc
CWpd16$"Y2016:FBornTc"<-1*CWpd16$FBornTc
CWpd16$"Y2017:FBornTc"<-0*CWpd16$FBornTc
CWpd16$"Y2018:FBornTc"<-0*CWpd16$FBornTc
CWpd17$"Y2016:FBornTc"<-0*CWpd17$FBornTc
CWpd17$"Y2017:FBornTc"<-1*CWpd17$FBornTc
CWpd17$"Y2018:FBornTc"<-0*CWpd17$FBornTc
CWpd18$"Y2016:FBornTc"<-0*CWpd18$FBornTc
CWpd18$"Y2017:FBornTc"<-0*CWpd18$FBornTc
CWpd18$"Y2018:FBornTc"<-1*CWpd18$FBornTc

round(quantile(CB$FBornT,c(0.025,0.975)))
CBpd<-data.frame(FBornT=seq(0,30,by=1))
CBpd$FBornTc   <-CBpd$FBornT-mean(CB$FBornT)
CBpd$PopHPc    <-mean(CB$PopHPc    )
CBpd$ICEArrYCRc<-mean(CB$ICEArrYCRc)
CBpd$PopBP     <-mean(CB$PopBP     )
CBpd$ChildPB   <-mean(CB$ChildPB   )
CBpd$MalePB    <-mean(CB$MalePB    )
CBpd$SingleB   <-mean(CB$SingleB   )
CBpd$NoHighB   <-mean(CB$NoHighB   )
CBpd$CPovB     <-mean(CB$CPovB     )
CBpd$HValueT   <-mean(CB$HValueT   )
CBpd$HInsurBC  <-mean(CB$HInsurBC  )
CBpd$MoveB     <-mean(CB$MoveB     )
CBpd$RUC2      <-mean(CB$RUC2      )
CBpd$RUC3      <-mean(CB$RUC3      )
CBpd15<-CBpd;CBpd15$Y2016<-0;CBpd15$Y2017<-0;CBpd15$Y2018<-0
CBpd16<-CBpd;CBpd16$Y2016<-1;CBpd16$Y2017<-0;CBpd16$Y2018<-0
CBpd17<-CBpd;CBpd17$Y2016<-0;CBpd17$Y2017<-1;CBpd17$Y2018<-0
CBpd18<-CBpd;CBpd18$Y2016<-0;CBpd18$Y2017<-0;CBpd18$Y2018<-1
CBpd15$"Y2016:FBornTc"<-0*CBpd15$FBornTc
CBpd15$"Y2017:FBornTc"<-0*CBpd15$FBornTc
CBpd15$"Y2018:FBornTc"<-0*CBpd15$FBornTc
CBpd16$"Y2016:FBornTc"<-1*CBpd16$FBornTc
CBpd16$"Y2017:FBornTc"<-0*CBpd16$FBornTc
CBpd16$"Y2018:FBornTc"<-0*CBpd16$FBornTc
CBpd17$"Y2016:FBornTc"<-0*CBpd17$FBornTc
CBpd17$"Y2017:FBornTc"<-1*CBpd17$FBornTc
CBpd17$"Y2018:FBornTc"<-0*CBpd17$FBornTc
CBpd18$"Y2016:FBornTc"<-0*CBpd18$FBornTc
CBpd18$"Y2017:FBornTc"<-0*CBpd18$FBornTc
CBpd18$"Y2018:FBornTc"<-1*CBpd18$FBornTc

round(quantile(CH$FBornT,c(0.025,0.975)))
CHpd<-data.frame(FBornT=seq(0,30,by=1))
CHpd$FBornTc   <-CHpd$FBornT-mean(CH$FBornT)
CHpd$PopHPc    <-mean(CH$PopHPc    )
CHpd$ICEArrYCRc<-mean(CH$ICEArrYCRc)
CHpd$PopBP     <-mean(CH$PopBP     )
CHpd$ChildPH   <-mean(CH$ChildPH   )
CHpd$MalePH    <-mean(CH$MalePH    )
CHpd$SingleH   <-mean(CH$SingleH   )
CHpd$NoHighH   <-mean(CH$NoHighH   )
CHpd$CPovH     <-mean(CH$CPovH     )
CHpd$HValueT   <-mean(CH$HValueT   )
CHpd$HInsurHC  <-mean(CH$HInsurHC  )
CHpd$MoveH     <-mean(CH$MoveH     )
CHpd$RUC2      <-mean(CH$RUC2      )
CHpd$RUC3      <-mean(CH$RUC3      )
CHpd15<-CHpd;CHpd15$Y2016<-0;CHpd15$Y2017<-0;CHpd15$Y2018<-0
CHpd16<-CHpd;CHpd16$Y2016<-1;CHpd16$Y2017<-0;CHpd16$Y2018<-0
CHpd17<-CHpd;CHpd17$Y2016<-0;CHpd17$Y2017<-1;CHpd17$Y2018<-0
CHpd18<-CHpd;CHpd18$Y2016<-0;CHpd18$Y2017<-0;CHpd18$Y2018<-1
CHpd15$"Y2016:FBornTc"<-0*CHpd15$FBornTc
CHpd15$"Y2017:FBornTc"<-0*CHpd15$FBornTc
CHpd15$"Y2018:FBornTc"<-0*CHpd15$FBornTc
CHpd16$"Y2016:FBornTc"<-1*CHpd16$FBornTc
CHpd16$"Y2017:FBornTc"<-0*CHpd16$FBornTc
CHpd16$"Y2018:FBornTc"<-0*CHpd16$FBornTc
CHpd17$"Y2016:FBornTc"<-0*CHpd17$FBornTc
CHpd17$"Y2017:FBornTc"<-1*CHpd17$FBornTc
CHpd17$"Y2018:FBornTc"<-0*CHpd17$FBornTc
CHpd18$"Y2016:FBornTc"<-0*CHpd18$FBornTc
CHpd18$"Y2017:FBornTc"<-0*CHpd18$FBornTc
CHpd18$"Y2018:FBornTc"<-1*CHpd18$FBornTc

CTpd15$y<-predict(CTm7,newdata=CTpd15,re.form=NA)
CTpd16$y<-predict(CTm7,newdata=CTpd16,re.form=NA)
CTpd17$y<-predict(CTm7,newdata=CTpd17,re.form=NA)
CTpd18$y<-predict(CTm7,newdata=CTpd18,re.form=NA)
CWpd15$y<-predict(CWm7,newdata=CWpd15,re.form=NA)
CWpd16$y<-predict(CWm7,newdata=CWpd16,re.form=NA)
CWpd17$y<-predict(CWm7,newdata=CWpd17,re.form=NA)
CWpd18$y<-predict(CWm7,newdata=CWpd18,re.form=NA)
CBpd15$y<-predict(CBm7,newdata=CBpd15,re.form=NA)
CBpd16$y<-predict(CBm7,newdata=CBpd16,re.form=NA)
CBpd17$y<-predict(CBm7,newdata=CBpd17,re.form=NA)
CBpd18$y<-predict(CBm7,newdata=CBpd18,re.form=NA)
CHpd15$y<-predict(CHm7,newdata=CHpd15,re.form=NA)
CHpd16$y<-predict(CHm7,newdata=CHpd16,re.form=NA)
CHpd17$y<-predict(CHm7,newdata=CHpd17,re.form=NA)
CHpd18$y<-predict(CHm7,newdata=CHpd18,re.form=NA)

Table2_2<-data.table(
  Tcoef=c(summary(CTm7 )$coef["FBornTc",1],summary(CTm7 )$coef["Y2016:FBornTc",1],summary(CTm7 )$coef["Y2017:FBornTc",1],summary(CTm7 )$coef["Y2018:FBornTc",1],summary(CTm7 )$coef["PopHPc",1],summary(CTm7 )$coef["ICEArrYCRc",1]),
  TLL  =c(        CTm7CI["FBornTc",1]     ,        CTm7CI["Y2016:FBornTc",1]     ,        CTm7CI["Y2017:FBornTc",1]     ,        CTm7CI["Y2018:FBornTc",1]     ,        CTm7CI["PopHPc",1]     ,        CTm7CI["ICEArrYCRc",1]     ),
  TUL  =c(        CTm7CI["FBornTc",2]     ,        CTm7CI["Y2016:FBornTc",2]     ,        CTm7CI["Y2017:FBornTc",2]     ,        CTm7CI["Y2018:FBornTc",2]     ,        CTm7CI["PopHPc",2]     ,        CTm7CI["ICEArrYCRc",2]     ),
  Wcoef=c(summary(CWm7 )$coef["FBornTc",1],summary(CWm7 )$coef["Y2016:FBornTc",1],summary(CWm7 )$coef["Y2017:FBornTc",1],summary(CWm7 )$coef["Y2018:FBornTc",1],summary(CWm7 )$coef["PopHPc",1],summary(CWm7 )$coef["ICEArrYCRc",1]),
  WLL  =c(        CWm7CI["FBornTc",1]     ,        CWm7CI["Y2016:FBornTc",1]     ,        CWm7CI["Y2017:FBornTc",1]     ,        CWm7CI["Y2018:FBornTc",1]     ,        CWm7CI["PopHPc",1]     ,        CWm7CI["ICEArrYCRc",1]     ),
  WUL  =c(        CWm7CI["FBornTc",2]     ,        CWm7CI["Y2016:FBornTc",2]     ,        CWm7CI["Y2017:FBornTc",2]     ,        CWm7CI["Y2018:FBornTc",2]     ,        CWm7CI["PopHPc",2]     ,        CWm7CI["ICEArrYCRc",2]     ),
  Bcoef=c(summary(CBm7 )$coef["FBornTc",1],summary(CBm7 )$coef["Y2016:FBornTc",1],summary(CBm7 )$coef["Y2017:FBornTc",1],summary(CBm7 )$coef["Y2018:FBornTc",1],summary(CBm7 )$coef["PopHPc",1],summary(CBm7 )$coef["ICEArrYCRc",1]),
  BLL  =c(        CBm7CI["FBornTc",1]     ,        CBm7CI["Y2016:FBornTc",1]     ,        CBm7CI["Y2017:FBornTc",1]     ,        CBm7CI["Y2018:FBornTc",1]     ,        CBm7CI["PopHPc",1]     ,        CBm7CI["ICEArrYCRc",1]     ),
  BUL  =c(        CBm7CI["FBornTc",2]     ,        CBm7CI["Y2016:FBornTc",2]     ,        CBm7CI["Y2017:FBornTc",2]     ,        CBm7CI["Y2018:FBornTc",2]     ,        CBm7CI["PopHPc",2]     ,        CBm7CI["ICEArrYCRc",2]     ),
  Hcoef=c(summary(CHm7 )$coef["FBornTc",1],summary(CHm7 )$coef["Y2016:FBornTc",1],summary(CHm7 )$coef["Y2017:FBornTc",1],summary(CHm7 )$coef["Y2018:FBornTc",1],summary(CHm7 )$coef["PopHPc",1],summary(CHm7 )$coef["ICEArrYCRc",1]),
  HLL  =c(        CHm7CI["FBornTc",1]     ,        CHm7CI["Y2016:FBornTc",1]     ,        CHm7CI["Y2017:FBornTc",1]     ,        CHm7CI["Y2018:FBornTc",1]     ,        CHm7CI["PopHPc",1]     ,        CHm7CI["ICEArrYCRc",1]     ),
  HUL  =c(        CHm7CI["FBornTc",2]     ,        CHm7CI["Y2016:FBornTc",2]     ,        CHm7CI["Y2017:FBornTc",2]     ,        CHm7CI["Y2018:FBornTc",2]     ,        CHm7CI["PopHPc",2]     ,        CHm7CI["ICEArrYCRc",2]     )
)
Table2_2
write.csv(Table2_2,"Z:/ICE_CM/Tables/Table2_2.csv")

summary(CTm7)
summary(CWm7)
summary(CBm7)
summary(CHm7)




Graph1<-data.table(
  TFB15=CTpd15$FBornT,TCM15=CTpd15$y,
  TFB16=CTpd16$FBornT,TCM16=CTpd16$y,
  TFB17=CTpd17$FBornT,TCM17=CTpd17$y,
  TFB18=CTpd18$FBornT,TCM18=CTpd18$y,
  WFB15=CWpd15$FBornT,WCM15=CWpd15$y,
  WFB16=CWpd16$FBornT,WCM16=CWpd16$y,
  WFB17=CWpd17$FBornT,WCM17=CWpd17$y,
  WFB18=CWpd18$FBornT,WCM18=CWpd18$y,
  BFB15=CBpd15$FBornT,BCM15=CBpd15$y,
  BFB16=CBpd16$FBornT,BCM16=CBpd16$y,
  BFB17=CBpd17$FBornT,BCM17=CBpd17$y,
  BFB18=CBpd18$FBornT,BCM18=CBpd18$y,
  HFB15=CHpd15$FBornT,HCM15=CHpd15$y,
  HFB16=CHpd16$FBornT,HCM16=CHpd16$y,
  HFB17=CHpd17$FBornT,HCM17=CHpd17$y,
  HFB18=CHpd18$FBornT,HCM18=CHpd18$y
)
Graph1
write.csv(Graph1,"Z:/ICE_CM/Tables/Graph1.csv")


summary(CTm7)
summary(CWm7)
summary(CBm7)
summary(CHm7)



save.image("Z:/ICE_CM/ICE02.RData")




devtools::install_github("remkoduursma/bootpredictlme4")
library(bootpredictlme4)

CTpd15p<-predict(CTm7,newdata=CTpd15,re.form=NA)




# Child Disability
# Child Disability
# Child Disability
# Child Disability
# Child Disability

# Centering Variables
mean(DT$PopHP)     
mean(DT$FBornT)    
mean(DT$ICEArrR)   
mean(DT$ICEArrYCR) 
mean(DW$PopHP)     
mean(DW$FBornT)    
mean(DW$ICEArrR)   
mean(DW$ICEArrYCR) 
mean(DB$PopHP)     
mean(DB$FBornT)    
mean(DB$ICEArrR)   
mean(DB$ICEArrYCR) 
mean(DH$PopHP)     
mean(DH$FBornT)    
mean(DH$ICEArrR)   
mean(DH$ICEArrYCR) 
DT$PopHPc    <-DT$PopHP    -mean(DT$PopHP)
DT$FBornTc   <-DT$FBornT   -mean(DT$FBornT)
DT$ICEArrRc  <-DT$ICEArrR  -mean(DT$ICEArrR)
DT$ICEArrYCRc<-DT$ICEArrYCR-mean(DT$ICEArrYCR)
DW$PopHPc    <-DW$PopHP    -mean(DW$PopHP)
DW$FBornTc   <-DW$FBornT   -mean(DW$FBornT)
DW$ICEArrRc  <-DW$ICEArrR  -mean(DW$ICEArrR)
DW$ICEArrYCRc<-DW$ICEArrYCR-mean(DW$ICEArrYCR)
DB$PopHPc    <-DB$PopHP    -mean(DB$PopHP)
DB$FBornTc   <-DB$FBornT   -mean(DB$FBornT)
DB$ICEArrRc  <-DB$ICEArrR  -mean(DB$ICEArrR)
DB$ICEArrYCRc<-DB$ICEArrYCR-mean(DB$ICEArrYCR)
DH$PopHPc    <-DH$PopHP    -mean(DH$PopHP)
DH$FBornTc   <-DH$FBornT   -mean(DH$FBornT)
DH$ICEArrRc  <-DH$ICEArrR  -mean(DH$ICEArrR)
DH$ICEArrYCRc<-DH$ICEArrYCR-mean(DH$ICEArrYCR)

# Modeling
DTm0  <-lmer(DisablTC~Year                                                                                                     +(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DTm1  <-lmer(DisablTC~Year+PopHPc                                                                                              +(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DTm2  <-lmer(DisablTC~Year+FBornTc                                                                                             +(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DTm4  <-lmer(DisablTC~Year+ICEArrYCRc                                                                                          +(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DTm5  <-lmer(DisablTC~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC         +(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DTm6  <-lmer(DisablTC~Year*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC         +(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DTm7  <-lmer(DisablTC~Year*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC         +(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DTm8  <-lmer(DisablTC~Year*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC         +(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DTm5a <-lmer(DisablTC~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+HInsurTC+(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DTm6a <-lmer(DisablTC~Year*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+HInsurTC+(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DTm7a <-lmer(DisablTC~Year*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+HInsurTC+(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DTm8a <-lmer(DisablTC~Year*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+HInsurTC+(1|CountyFIPS)+(1|StateFIPS),data=DT,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DWm0  <-lmer(DisablWC~Year                                                                                                     +(1|CountyFIPS)+(1|StateFIPS),data=DW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DWm1  <-lmer(DisablWC~Year+PopHPc                                                                                              +(1|CountyFIPS)+(1|StateFIPS),data=DW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DWm2  <-lmer(DisablWC~Year+FBornTc                                                                                             +(1|CountyFIPS)+(1|StateFIPS),data=DW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DWm4  <-lmer(DisablWC~Year+ICEArrYCRc                                                                                          +(1|CountyFIPS)+(1|StateFIPS),data=DW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DWm5  <-lmer(DisablWC~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+MoveW+USDA_RUC         +(1|CountyFIPS)+(1|StateFIPS),data=DW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DWm5a <-lmer(DisablWC~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+HInsurWC+MoveW+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DWm6a <-lmer(DisablWC~Year*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+HInsurWC+MoveW+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DWm7a <-lmer(DisablWC~Year*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+HInsurWC+MoveW+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DWm8a <-lmer(DisablWC~Year*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+HInsurWC+MoveW+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DW,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DBm0  <-lmer(DisablBC~Year                                                                                                     +(1|CountyFIPS)+(1|StateFIPS),data=DB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DBm1  <-lmer(DisablBC~Year+PopHPc                                                                                              +(1|CountyFIPS)+(1|StateFIPS),data=DB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DBm2  <-lmer(DisablBC~Year+FBornTc                                                                                             +(1|CountyFIPS)+(1|StateFIPS),data=DB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DBm4  <-lmer(DisablBC~Year+ICEArrYCRc                                                                                          +(1|CountyFIPS)+(1|StateFIPS),data=DB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DBm5  <-lmer(DisablBC~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+MoveB+USDA_RUC         +(1|CountyFIPS)+(1|StateFIPS),data=DB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DBm5a <-lmer(DisablBC~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+HInsurBC+MoveB+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DBm6a <-lmer(DisablBC~Year*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+HInsurBC+MoveB+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DBm7a <-lmer(DisablBC~Year*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+HInsurBC+MoveB+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DBm8a <-lmer(DisablBC~Year*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+HInsurBC+MoveB+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DB,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DHm0  <-lmer(DisablHC~Year                                                                                                     +(1|CountyFIPS)+(1|StateFIPS),data=DH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DHm1  <-lmer(DisablHC~Year+PopHPc                                                                                              +(1|CountyFIPS)+(1|StateFIPS),data=DH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DHm2  <-lmer(DisablHC~Year+FBornTc                                                                                             +(1|CountyFIPS)+(1|StateFIPS),data=DH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DHm4  <-lmer(DisablHC~Year+ICEArrYCRc                                                                                          +(1|CountyFIPS)+(1|StateFIPS),data=DH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DHm5  <-lmer(DisablHC~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+MoveH+USDA_RUC         +(1|CountyFIPS)+(1|StateFIPS),data=DH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DHm5a <-lmer(DisablHC~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+HInsurHC+MoveH+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DHm6a <-lmer(DisablHC~Year*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+HInsurHC+MoveH+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DHm7a <-lmer(DisablHC~Year*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+HInsurHC+MoveH+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
DHm8a <-lmer(DisablHC~Year*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+HInsurHC+MoveH+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=DH,control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

# Formal Test for Interaction
anova(DTm5a,DTm6a )
anova(DTm5a,DTm7a )
anova(DTm5a,DTm8a )
summary(DTm5a)
summary(DTm6a)
summary(DTm7a)
summary(DTm8a)

anova(DWm5a,DWm6a )
anova(DWm5a,DWm7a )
anova(DWm5a,DWm8a )
summary(DWm5a)
summary(DWm6a)
summary(DWm7a)
summary(DWm8a)

anova(DBm5a,DBm6a )
anova(DBm5a,DBm7a )
anova(DBm5a,DBm8a )
summary(DBm5a)
summary(DBm6a)
summary(DBm7a)
summary(DBm8a)

anova(DHm5a,DHm6a )
anova(DHm5a,DHm7a )
anova(DHm5a,DHm8a )
summary(DHm5a)
summary(DHm6a)
summary(DHm7a)
summary(DHm8a)

# bootstrap confidence interval
DTm1CI <-confint(DTm1 ,method='boot',nsim=500,boot.type='perc')
DTm2CI <-confint(DTm2 ,method='boot',nsim=500,boot.type='perc')
DTm4CI <-confint(DTm4 ,method='boot',nsim=500,boot.type='perc')
# DTm5CI <-confint(DTm5 ,method='boot',nsim=500,boot.type='perc')
DTm5aCI<-confint(DTm5a,method='boot',nsim=500,boot.type='perc')
DWm1CI <-confint(DWm1 ,method='boot',nsim=500,boot.type='perc')
DWm2CI <-confint(DWm2 ,method='boot',nsim=500,boot.type='perc')
DWm4CI <-confint(DWm4 ,method='boot',nsim=500,boot.type='perc')
# DWm5CI <-confint(DWm5 ,method='boot',nsim=500,boot.type='perc')
DWm5aCI<-confint(DWm5a,method='boot',nsim=500,boot.type='perc')
DBm1CI <-confint(DBm1 ,method='boot',nsim=500,boot.type='perc')
DBm2CI <-confint(DBm2 ,method='boot',nsim=500,boot.type='perc')
DBm4CI <-confint(DBm4 ,method='boot',nsim=500,boot.type='perc')
# DBm5CI <-confint(DBm5 ,method='boot',nsim=500,boot.type='perc')
DBm5aCI<-confint(DBm5a,method='boot',nsim=500,boot.type='perc')
DHm1CI <-confint(DHm1 ,method='boot',nsim=500,boot.type='perc')
DHm2CI <-confint(DHm2 ,method='boot',nsim=500,boot.type='perc')
DHm4CI <-confint(DHm4 ,method='boot',nsim=500,boot.type='perc')
# DHm5CI <-confint(DHm5 ,method='boot',nsim=500,boot.type='perc')
DHm5aCI<-confint(DHm5a,method='boot',nsim=500,boot.type='perc')





Table2<-data.table(
  Tcoef=c(summary(CTm2 )$coef["FBornTc",1],summary(CTm1 )$coef["PopHPc",1],summary(CTm4 )$coef["ICEArrYCRc",1],summary(DTm2 )$coef["FBornTc",1],summary(DTm1 )$coef["PopHPc",1],summary(DTm4 )$coef["ICEArrYCRc",1]),
  TLL=c(          CTm2CI["FBornTc",1],             CTm1CI["PopHPc",1],             CTm4CI["ICEArrYCRc",1],             DTm2CI["FBornTc",1],             DTm1CI["PopHPc",1],             DTm4CI["ICEArrYCRc",1]),
  TUL=c(          CTm2CI["FBornTc",2],             CTm1CI["PopHPc",2],             CTm4CI["ICEArrYCRc",2],             DTm2CI["FBornTc",2],             DTm1CI["PopHPc",2],             DTm4CI["ICEArrYCRc",2]),
  Wcoef=c(summary(CWm2 )$coef["FBornTc",1],summary(CWm1 )$coef["PopHPc",1],summary(CWm4 )$coef["ICEArrYCRc",1],summary(DWm2 )$coef["FBornTc",1],summary(DWm1 )$coef["PopHPc",1],summary(DWm4 )$coef["ICEArrYCRc",1]),
  WLL=c(          CWm2CI["FBornTc",1],             CWm1CI["PopHPc",1],             CWm4CI["ICEArrYCRc",1],             DWm2CI["FBornTc",1],             DWm1CI["PopHPc",1],             DWm4CI["ICEArrYCRc",1]),
  WUL=c(          CWm2CI["FBornTc",2],             CWm1CI["PopHPc",2],             CWm4CI["ICEArrYCRc",2],             DWm2CI["FBornTc",2],             DWm1CI["PopHPc",2],             DWm4CI["ICEArrYCRc",2]),
  Bcoef=c(summary(CBm2 )$coef["FBornTc",1],summary(CBm1 )$coef["PopHPc",1],summary(CBm4 )$coef["ICEArrYCRc",1],summary(DBm2 )$coef["FBornTc",1],summary(DBm1 )$coef["PopHPc",1],summary(DBm4 )$coef["ICEArrYCRc",1]),
  BLL=c(          CBm2CI["FBornTc",1],             CBm1CI["PopHPc",1],             CBm4CI["ICEArrYCRc",1],             DBm2CI["FBornTc",1],             DBm1CI["PopHPc",1],             DBm4CI["ICEArrYCRc",1]),
  BUL=c(          CBm2CI["FBornTc",2],             CBm1CI["PopHPc",2],             CBm4CI["ICEArrYCRc",2],             DBm2CI["FBornTc",2],             DBm1CI["PopHPc",2],             DBm4CI["ICEArrYCRc",2]),
  Hcoef=c(summary(CHm2 )$coef["FBornTc",1],summary(CHm1 )$coef["PopHPc",1],summary(CHm4 )$coef["ICEArrYCRc",1],summary(DHm2 )$coef["FBornTc",1],summary(DHm1 )$coef["PopHPc",1],summary(DHm4 )$coef["ICEArrYCRc",1]),
  HLL=c(          CHm2CI["FBornTc",1],             CHm1CI["PopHPc",1],             CHm4CI["ICEArrYCRc",1],             DHm2CI["FBornTc",1],             DHm1CI["PopHPc",1],             DHm4CI["ICEArrYCRc",1]),
  HUL=c(          CHm2CI["FBornTc",2],             CHm1CI["PopHPc",2],             CHm4CI["ICEArrYCRc",2],             DHm2CI["FBornTc",2],             DHm1CI["PopHPc",2],             DHm4CI["ICEArrYCRc",2])
)
Table2
write.csv(Table2,"Z:/ICE_CM/Tables/Table2.csv")





Table3<-data.table(
  Tcoef=c(summary(CTm5a )$coef["FBornTc",1],summary(CTm5a )$coef["PopHPc",1],summary(CTm5a )$coef["ICEArrYCRc",1],summary(DTm5a )$coef["FBornTc",1],summary(DTm5a )$coef["PopHPc",1],summary(DTm5a )$coef["ICEArrYCRc",1]),
  TLL=c(          CTm5aCI["FBornTc",1],             CTm5aCI["PopHPc",1],             CTm5aCI["ICEArrYCRc",1],             DTm5aCI["FBornTc",1],             DTm5aCI["PopHPc",1],             DTm5aCI["ICEArrYCRc",1]),
  TUL=c(          CTm5aCI["FBornTc",2],             CTm5aCI["PopHPc",2],             CTm5aCI["ICEArrYCRc",2],             DTm5aCI["FBornTc",2],             DTm5aCI["PopHPc",2],             DTm5aCI["ICEArrYCRc",2]),
  Wcoef=c(summary(CWm5a )$coef["FBornTc",1],summary(CWm5a )$coef["PopHPc",1],summary(CWm5a )$coef["ICEArrYCRc",1],summary(DWm5a )$coef["FBornTc",1],summary(DWm5a )$coef["PopHPc",1],summary(DWm5a )$coef["ICEArrYCRc",1]),
  WLL=c(          CWm5aCI["FBornTc",1],             CWm5aCI["PopHPc",1],             CWm5aCI["ICEArrYCRc",1],             DWm5aCI["FBornTc",1],             DWm5aCI["PopHPc",1],             DWm5aCI["ICEArrYCRc",1]),
  WUL=c(          CWm5aCI["FBornTc",2],             CWm5aCI["PopHPc",2],             CWm5aCI["ICEArrYCRc",2],             DWm5aCI["FBornTc",2],             DWm5aCI["PopHPc",2],             DWm5aCI["ICEArrYCRc",2]),
  Bcoef=c(summary(CBm5a )$coef["FBornTc",1],summary(CBm5a )$coef["PopHPc",1],summary(CBm5a )$coef["ICEArrYCRc",1],summary(DBm5a )$coef["FBornTc",1],summary(DBm5a )$coef["PopHPc",1],summary(DBm5a )$coef["ICEArrYCRc",1]),
  BLL=c(          CBm5aCI["FBornTc",1],             CBm5aCI["PopHPc",1],             CBm5aCI["ICEArrYCRc",1],             DBm5aCI["FBornTc",1],             DBm5aCI["PopHPc",1],             DBm5aCI["ICEArrYCRc",1]),
  BUL=c(          CBm5aCI["FBornTc",2],             CBm5aCI["PopHPc",2],             CBm5aCI["ICEArrYCRc",2],             DBm5aCI["FBornTc",2],             DBm5aCI["PopHPc",2],             DBm5aCI["ICEArrYCRc",2]),
  Hcoef=c(summary(CHm5a )$coef["FBornTc",1],summary(CHm5a )$coef["PopHPc",1],summary(CHm5a )$coef["ICEArrYCRc",1],summary(DHm5a )$coef["FBornTc",1],summary(DHm5a )$coef["PopHPc",1],summary(DHm5a )$coef["ICEArrYCRc",1]),
  HLL=c(          CHm5aCI["FBornTc",1],             CHm5aCI["PopHPc",1],             CHm5aCI["ICEArrYCRc",1],             DHm5aCI["FBornTc",1],             DHm5aCI["PopHPc",1],             DHm5aCI["ICEArrYCRc",1]),
  HUL=c(          CHm5aCI["FBornTc",2],             CHm5aCI["PopHPc",2],             CHm5aCI["ICEArrYCRc",2],             DHm5aCI["FBornTc",2],             DHm5aCI["PopHPc",2],             DHm5aCI["ICEArrYCRc",2])
)
Table3
write.csv(Table3,"Z:/ICE_CM/Tables/Table3.csv")





skewness(summary(CTm5a )$resid)
skewness(summary(CWm5a )$resid)
skewness(summary(CBm5a )$resid)
skewness(summary(CHm5a )$resid)
skewness(summary(DTm5a )$resid)
skewness(summary(DWm5a )$resid)
skewness(summary(DBm5a )$resid)
skewness(summary(DHm5a )$resid)





# Low Birth Weight
# Low Birth Weight
# Low Birth Weight
# Low Birth Weight
# Low Birth Weight

# Centering Variables
mean(LT$PopHP)     
mean(LT$FBornT)    
mean(LT$ICEArrR)   
mean(LT$ICEArrYCR) 
mean(LW$PopHP)     
mean(LW$FBornT)    
mean(LW$ICEArrR)   
mean(LW$ICEArrYCR) 
mean(LB$PopHP)     
mean(LB$FBornT)    
mean(LB$ICEArrR)   
mean(LB$ICEArrYCR) 
mean(LH$PopHP)     
mean(LH$FBornT)    
mean(LH$ICEArrR)   
mean(LH$ICEArrYCR) 
LT$PopHPc    <-LT$PopHP    -mean(LT$PopHP)
LT$FBornTc   <-LT$FBornT   -mean(LT$FBornT)
LT$ICEArrRc  <-LT$ICEArrR  -mean(LT$ICEArrR)
LT$ICEArrYCRc<-LT$ICEArrYCR-mean(LT$ICEArrYCR)
LW$PopHPc    <-LW$PopHP    -mean(LW$PopHP)
LW$FBornTc   <-LW$FBornT   -mean(LW$FBornT)
LW$ICEArrRc  <-LW$ICEArrR  -mean(LW$ICEArrR)
LW$ICEArrYCRc<-LW$ICEArrYCR-mean(LW$ICEArrYCR)
LB$PopHPc    <-LB$PopHP    -mean(LB$PopHP)
LB$FBornTc   <-LB$FBornT   -mean(LB$FBornT)
LB$ICEArrRc  <-LB$ICEArrR  -mean(LB$ICEArrR)
LB$ICEArrYCRc<-LB$ICEArrYCR-mean(LB$ICEArrYCR)
LH$PopHPc    <-LH$PopHP    -mean(LH$PopHP)
LH$FBornTc   <-LH$FBornT   -mean(LH$FBornT)
LH$ICEArrRc  <-LH$ICEArrR  -mean(LH$ICEArrR)
LH$ICEArrYCRc<-LH$ICEArrYCR-mean(LH$ICEArrYCR)

# Modeling
LTm0 <-lmer(LBWT1r~Year                                                                                           +(1|StateFIPS),data=LT)
LTm1 <-lmer(LBWT1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=LT)
LTm2 <-lmer(LBWT1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=LT)
LTm3 <-lmer(LBWT1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=LT)
LTm4 <-lmer(LBWT1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=LT)
LTm5 <-lmer(LBWT1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=LT)
LTm6 <-lmer(LBWT1r~Year*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=LT)
LTm7 <-lmer(LBWT1r~Year*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=LT)
LTm8 <-lmer(LBWT1r~Year*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=LT)
LTm9 <-lmer(LBWT1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=LT)
LTm10<-lmer(LBWT1r~Year*PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=LT)
LTm11<-lmer(LBWT1r~Year*FBornTc+PopHPc+ICEArrRc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=LT)
LTm12<-lmer(LBWT1r~Year*ICEArrRc+PopHPc+FBornTc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=LT)
LWm0 <-lmer(LBWW1r~Year                                                                                           +(1|StateFIPS),data=LW)
LWm1 <-lmer(LBWW1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=LW)
LWm2 <-lmer(LBWW1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=LW)
LWm3 <-lmer(LBWW1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=LW)
LWm4 <-lmer(LBWW1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=LW)
LWm5 <-lmer(LBWW1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+MoveW+USDA_RUC+(1|StateFIPS),data=LW)
LWm6 <-lmer(LBWW1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+MoveW+USDA_RUC+(1|StateFIPS),data=LW)
LBm0 <-lmer(LBWB1r~Year                                                                                           +(1|StateFIPS),data=LB)
LBm1 <-lmer(LBWB1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=LB)
LBm2 <-lmer(LBWB1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=LB)
LBm3 <-lmer(LBWB1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=LB)
LBm4 <-lmer(LBWB1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=LB)
LBm5 <-lmer(LBWB1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+MoveB+USDA_RUC+(1|StateFIPS),data=LB)
LBm6 <-lmer(LBWB1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+MoveB+USDA_RUC+(1|StateFIPS),data=LB)
LHm0 <-lmer(LBWH1r~Year                                                                                           +(1|StateFIPS),data=LH)
LHm1 <-lmer(LBWH1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=LH)
LHm2 <-lmer(LBWH1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=LH)
LHm3 <-lmer(LBWH1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=LH)
LHm4 <-lmer(LBWH1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=LH)
LHm5 <-lmer(LBWH1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+MoveH+USDA_RUC+(1|StateFIPS),data=LH)
LHm6 <-lmer(LBWH1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+MoveH+USDA_RUC+(1|StateFIPS),data=LH)

summary(LTm0 )
summary(LTm1 )
summary(LTm2 )
summary(LTm3 )
summary(LTm4 )
summary(LTm5 ) 
summary(LTm6 )
summary(LTm7 )
summary(LTm8 )
summary(LTm9 )
summary(LTm10)
summary(LTm11)
summary(LTm12)
summary(LWm0 )
summary(LWm1 )
summary(LWm2 )
summary(LWm3 )
summary(LWm4 )
summary(LWm5 ) 
summary(LWm6 )
summary(LBm0 )
summary(LBm1 )
summary(LBm2 )
summary(LBm3 )
summary(LBm4 )
summary(LBm5 ) 
summary(LBm6 )
summary(LHm0 )
summary(LHm1 )
summary(LHm2 )
summary(LHm3 )
summary(LHm4 )
summary(LHm5 ) 
summary(LHm6 )

# Model Fit
AIC(
  LTm0 ,
  LTm1 ,
  LTm2 ,
  LTm3 ,
  LTm4 ,
  LTm5 ,
  LTm6 ,
  LTm7 ,
  LTm8 ,
  LTm9 ,
  LTm10,
  LTm11,
  LTm12)
AIC(
  LWm0,
  LWm1,
  LWm2,
  LWm3,
  LWm4,
  LWm5,
  LWm6)
AIC(
  LBm0,
  LBm1,
  LBm2,
  LBm3,
  LBm4,
  LBm5,
  LBm6)
AIC(
  LHm0,
  LHm1,
  LHm2,
  LHm3,
  LHm4,
  LHm5,
  LHm6)

# Formal Test for Interaction
anova(LTm5,LTm6 )
anova(LTm5,LTm7 )
anova(LTm5,LTm8 )
anova(LTm9,LTm10)
anova(LTm9,LTm11)
anova(LTm9,LTm12)

# VIF
check_collinearity(LTm5 )
check_collinearity(LTm6 )
check_collinearity(LTm7 )
check_collinearity(LTm8 )
check_collinearity(LTm9 )
check_collinearity(LTm10)
check_collinearity(LTm11)
check_collinearity(LTm12)
check_collinearity(LWm5 )
check_collinearity(LWm6 )
check_collinearity(LBm5 )
check_collinearity(LBm6 )
check_collinearity(LHm5 )
check_collinearity(LHm6 )

# bootstrap confidence interval
LTm0CI <-confint(LTm0 ,method='boot',nsim=500,boot.type='perc')
LTm1CI <-confint(LTm1 ,method='boot',nsim=500,boot.type='perc')
LTm2CI <-confint(LTm2 ,method='boot',nsim=500,boot.type='perc')
LTm3CI <-confint(LTm3 ,method='boot',nsim=500,boot.type='perc')
LTm4CI <-confint(LTm4 ,method='boot',nsim=500,boot.type='perc')
LTm5CI <-confint(LTm5 ,method='boot',nsim=500,boot.type='perc')
LTm6CI <-confint(LTm6 ,method='boot',nsim=500,boot.type='perc')
LTm7CI <-confint(LTm7 ,method='boot',nsim=500,boot.type='perc')
LTm8CI <-confint(LTm8 ,method='boot',nsim=500,boot.type='perc')
LTm9CI <-confint(LTm9 ,method='boot',nsim=500,boot.type='perc')
LTm10CI<-confint(LTm10,method='boot',nsim=500,boot.type='perc')
LTm11CI<-confint(LTm11,method='boot',nsim=500,boot.type='perc')
LTm12CI<-confint(LTm12,method='boot',nsim=500,boot.type='perc')
LWm0CI <-confint(LWm0 ,method='boot',nsim=500,boot.type='perc')
LWm1CI <-confint(LWm1 ,method='boot',nsim=500,boot.type='perc')
LWm2CI <-confint(LWm2 ,method='boot',nsim=500,boot.type='perc')
LWm3CI <-confint(LWm3 ,method='boot',nsim=500,boot.type='perc')
LWm4CI <-confint(LWm4 ,method='boot',nsim=500,boot.type='perc')
LWm5CI <-confint(LWm5 ,method='boot',nsim=500,boot.type='perc')
LWm6CI <-confint(LWm6 ,method='boot',nsim=500,boot.type='perc')
LBm0CI <-confint(LBm0 ,method='boot',nsim=500,boot.type='perc')
LBm1CI <-confint(LBm1 ,method='boot',nsim=500,boot.type='perc')
LBm2CI <-confint(LBm2 ,method='boot',nsim=500,boot.type='perc')
LBm3CI <-confint(LBm3 ,method='boot',nsim=500,boot.type='perc')
LBm4CI <-confint(LBm4 ,method='boot',nsim=500,boot.type='perc')
LBm5CI <-confint(LBm5 ,method='boot',nsim=500,boot.type='perc')
LBm6CI <-confint(LBm6 ,method='boot',nsim=500,boot.type='perc')
LHm0CI <-confint(LHm0 ,method='boot',nsim=500,boot.type='perc')
LHm1CI <-confint(LHm1 ,method='boot',nsim=500,boot.type='perc')
LHm2CI <-confint(LHm2 ,method='boot',nsim=500,boot.type='perc')
LHm3CI <-confint(LHm3 ,method='boot',nsim=500,boot.type='perc')
LHm4CI <-confint(LHm4 ,method='boot',nsim=500,boot.type='perc')
LHm5CI <-confint(LHm5 ,method='boot',nsim=500,boot.type='perc')
LHm6CI <-confint(LHm6 ,method='boot',nsim=500,boot.type='perc')

summary(LTm0 )$coef;LTm0CI 
summary(LTm1 )$coef;LTm1CI 
summary(LTm2 )$coef;LTm2CI 
summary(LTm3 )$coef;LTm3CI 
summary(LTm4 )$coef;LTm4CI 
summary(LTm5 )$coef;LTm5CI 
summary(LTm6 )$coef;LTm6CI 
summary(LTm7 )$coef;LTm7CI 
summary(LTm8 )$coef;LTm8CI 
summary(LTm9 )$coef;LTm9CI 
summary(LTm10)$coef;LTm10CI
summary(LTm11)$coef;LTm11CI
summary(LTm12)$coef;LTm12CI
summary(LWm0 )$coef;LWm0CI 
summary(LWm1 )$coef;LWm1CI 
summary(LWm2 )$coef;LWm2CI 
summary(LWm3 )$coef;LWm3CI 
summary(LWm4 )$coef;LWm4CI 
summary(LWm5 )$coef;LWm5CI 
summary(LWm6 )$coef;LWm6CI 
summary(LBm0 )$coef;LBm0CI 
summary(LBm1 )$coef;LBm1CI 
summary(LBm2 )$coef;LBm2CI 
summary(LBm3 )$coef;LBm3CI 
summary(LBm4 )$coef;LBm4CI 
summary(LBm5 )$coef;LBm5CI 
summary(LBm6 )$coef;LBm6CI 
summary(LHm0 )$coef;LHm0CI 
summary(LHm1 )$coef;LHm1CI 
summary(LHm2 )$coef;LHm2CI 
summary(LHm3 )$coef;LHm3CI 
summary(LHm4 )$coef;LHm4CI 
summary(LHm5 )$coef;LHm5CI 
summary(LHm6 )$coef;LHm6CI 





# Preterm Birth
# Preterm Birth
# Preterm Birth
# Preterm Birth
# Preterm Birth

# Centering Variables
mean(PT$PopHP)     
mean(PT$FBornT)    
mean(PT$ICEArrR)   
mean(PT$ICEArrYCR) 
mean(PW$PopHP)     
mean(PW$FBornT)    
mean(PW$ICEArrR)   
mean(PW$ICEArrYCR) 
mean(PB$PopHP)     
mean(PB$FBornT)    
mean(PB$ICEArrR)   
mean(PB$ICEArrYCR) 
mean(PH$PopHP)     
mean(PH$FBornT)    
mean(PH$ICEArrR)   
mean(PH$ICEArrYCR) 
PT$PopHPc    <-PT$PopHP    -mean(PT$PopHP)
PT$FBornTc   <-PT$FBornT   -mean(PT$FBornT)
PT$ICEArrRc  <-PT$ICEArrR  -mean(PT$ICEArrR)
PT$ICEArrYCRc<-PT$ICEArrYCR-mean(PT$ICEArrYCR)
PW$PopHPc    <-PW$PopHP    -mean(PW$PopHP)
PW$FBornTc   <-PW$FBornT   -mean(PW$FBornT)
PW$ICEArrRc  <-PW$ICEArrR  -mean(PW$ICEArrR)
PW$ICEArrYCRc<-PW$ICEArrYCR-mean(PW$ICEArrYCR)
PB$PopHPc    <-PB$PopHP    -mean(PB$PopHP)
PB$FBornTc   <-PB$FBornT   -mean(PB$FBornT)
PB$ICEArrRc  <-PB$ICEArrR  -mean(PB$ICEArrR)
PB$ICEArrYCRc<-PB$ICEArrYCR-mean(PB$ICEArrYCR)
PH$PopHPc    <-PH$PopHP    -mean(PH$PopHP)
PH$FBornTc   <-PH$FBornT   -mean(PH$FBornT)
PH$ICEArrRc  <-PH$ICEArrR  -mean(PH$ICEArrR)
PH$ICEArrYCRc<-PH$ICEArrYCR-mean(PH$ICEArrYCR)

# Modeling
PTm0 <-lmer(PTBT1r~Year                                                                                           +(1|StateFIPS),data=PT)
PTm1 <-lmer(PTBT1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=PT)
PTm2 <-lmer(PTBT1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=PT)
PTm3 <-lmer(PTBT1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=PT)
PTm4 <-lmer(PTBT1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=PT)
PTm5 <-lmer(PTBT1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=PT)
PTm6 <-lmer(PTBT1r~Year*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=PT)
PTm7 <-lmer(PTBT1r~Year*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=PT)
PTm8 <-lmer(PTBT1r~Year*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=PT)
PTm9 <-lmer(PTBT1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=PT)
PTm10<-lmer(PTBT1r~Year*PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=PT)
PTm11<-lmer(PTBT1r~Year*FBornTc+PopHPc+ICEArrRc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=PT)
PTm12<-lmer(PTBT1r~Year*ICEArrRc+PopHPc+FBornTc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=PT)
PWm0 <-lmer(PTBW1r~Year                                                                                           +(1|StateFIPS),data=PW)
PWm1 <-lmer(PTBW1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=PW)
PWm2 <-lmer(PTBW1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=PW)
PWm3 <-lmer(PTBW1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=PW)
PWm4 <-lmer(PTBW1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=PW)
PWm5 <-lmer(PTBW1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+MoveW+USDA_RUC+(1|StateFIPS),data=PW)
PWm6 <-lmer(PTBW1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+MoveW+USDA_RUC+(1|StateFIPS),data=PW)
PBm0 <-lmer(PTBB1r~Year                                                                                           +(1|StateFIPS),data=PB)
PBm1 <-lmer(PTBB1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=PB)
PBm2 <-lmer(PTBB1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=PB)
PBm3 <-lmer(PTBB1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=PB)
PBm4 <-lmer(PTBB1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=PB)
PBm5 <-lmer(PTBB1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+MoveB+USDA_RUC+(1|StateFIPS),data=PB)
PBm6 <-lmer(PTBB1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+MoveB+USDA_RUC+(1|StateFIPS),data=PB)
PHm0 <-lmer(PTBH1r~Year                                                                                           +(1|StateFIPS),data=PH)
PHm1 <-lmer(PTBH1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=PH)
PHm2 <-lmer(PTBH1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=PH)
PHm3 <-lmer(PTBH1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=PH)
PHm4 <-lmer(PTBH1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=PH)
PHm5 <-lmer(PTBH1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+MoveH+USDA_RUC+(1|StateFIPS),data=PH)
PHm6 <-lmer(PTBH1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+MoveH+USDA_RUC+(1|StateFIPS),data=PH)

summary(PTm0 )
summary(PTm1 )
summary(PTm2 )
summary(PTm3 )
summary(PTm4 )
summary(PTm5 ) 
summary(PTm6 )
summary(PTm7 )
summary(PTm8 )
summary(PTm9 )
summary(PTm10)
summary(PTm11)
summary(PTm12)
summary(PWm0 )
summary(PWm1 )
summary(PWm2 )
summary(PWm3 )
summary(PWm4 )
summary(PWm5 ) 
summary(PWm6 )
summary(PBm0 )
summary(PBm1 )
summary(PBm2 )
summary(PBm3 )
summary(PBm4 )
summary(PBm5 ) 
summary(PBm6 )
summary(PHm0 )
summary(PHm1 )
summary(PHm2 )
summary(PHm3 )
summary(PHm4 )
summary(PHm5 ) 
summary(PHm6 )

# Model Fit
AIC(
  PTm0 ,
  PTm1 ,
  PTm2 ,
  PTm3 ,
  PTm4 ,
  PTm5 ,
  PTm6 ,
  PTm7 ,
  PTm8 ,
  PTm9 ,
  PTm10,
  PTm11,
  PTm12)
AIC(
  PWm0,
  PWm1,
  PWm2,
  PWm3,
  PWm4,
  PWm5,
  PWm6)
AIC(
  PBm0,
  PBm1,
  PBm2,
  PBm3,
  PBm4,
  PBm5,
  PBm6)
AIC(
  PHm0,
  PHm1,
  PHm2,
  PHm3,
  PHm4,
  PHm5,
  PHm6)

# Formal Test for Interaction
anova(PTm5,PTm6 )
anova(PTm5,PTm7 )
anova(PTm5,PTm8 )
anova(PTm9,PTm10)
anova(PTm9,PTm11)
anova(PTm9,PTm12)

# VIF
check_collinearity(PTm5 )
check_collinearity(PTm6 )
check_collinearity(PTm7 )
check_collinearity(PTm8 )
check_collinearity(PTm9 )
check_collinearity(PTm10)
check_collinearity(PTm11)
check_collinearity(PTm12)
check_collinearity(PWm5 )
check_collinearity(PWm6 )
check_collinearity(PBm5 )
check_collinearity(PBm6 )
check_collinearity(PHm5 )
check_collinearity(PHm6 )

# bootstrap confidence interval
PTm0CI <-confint(PTm0 ,method='boot',nsim=500,boot.type='perc')
PTm1CI <-confint(PTm1 ,method='boot',nsim=500,boot.type='perc')
PTm2CI <-confint(PTm2 ,method='boot',nsim=500,boot.type='perc')
PTm3CI <-confint(PTm3 ,method='boot',nsim=500,boot.type='perc')
PTm4CI <-confint(PTm4 ,method='boot',nsim=500,boot.type='perc')
PTm5CI <-confint(PTm5 ,method='boot',nsim=500,boot.type='perc')
PTm6CI <-confint(PTm6 ,method='boot',nsim=500,boot.type='perc')
PTm7CI <-confint(PTm7 ,method='boot',nsim=500,boot.type='perc')
PTm8CI <-confint(PTm8 ,method='boot',nsim=500,boot.type='perc')
PTm9CI <-confint(PTm9 ,method='boot',nsim=500,boot.type='perc')
PTm10CI<-confint(PTm10,method='boot',nsim=500,boot.type='perc')
PTm11CI<-confint(PTm11,method='boot',nsim=500,boot.type='perc')
PTm12CI<-confint(PTm12,method='boot',nsim=500,boot.type='perc')
PWm0CI <-confint(PWm0 ,method='boot',nsim=500,boot.type='perc')
PWm1CI <-confint(PWm1 ,method='boot',nsim=500,boot.type='perc')
PWm2CI <-confint(PWm2 ,method='boot',nsim=500,boot.type='perc')
PWm3CI <-confint(PWm3 ,method='boot',nsim=500,boot.type='perc')
PWm4CI <-confint(PWm4 ,method='boot',nsim=500,boot.type='perc')
PWm5CI <-confint(PWm5 ,method='boot',nsim=500,boot.type='perc')
PWm6CI <-confint(PWm6 ,method='boot',nsim=500,boot.type='perc')
PBm0CI <-confint(PBm0 ,method='boot',nsim=500,boot.type='perc')
PBm1CI <-confint(PBm1 ,method='boot',nsim=500,boot.type='perc')
PBm2CI <-confint(PBm2 ,method='boot',nsim=500,boot.type='perc')
PBm3CI <-confint(PBm3 ,method='boot',nsim=500,boot.type='perc')
PBm4CI <-confint(PBm4 ,method='boot',nsim=500,boot.type='perc')
PBm5CI <-confint(PBm5 ,method='boot',nsim=500,boot.type='perc')
PBm6CI <-confint(PBm6 ,method='boot',nsim=500,boot.type='perc')
PHm0CI <-confint(PHm0 ,method='boot',nsim=500,boot.type='perc')
PHm1CI <-confint(PHm1 ,method='boot',nsim=500,boot.type='perc')
PHm2CI <-confint(PHm2 ,method='boot',nsim=500,boot.type='perc')
PHm3CI <-confint(PHm3 ,method='boot',nsim=500,boot.type='perc')
PHm4CI <-confint(PHm4 ,method='boot',nsim=500,boot.type='perc')
PHm5CI <-confint(PHm5 ,method='boot',nsim=500,boot.type='perc')
PHm6CI <-confint(PHm6 ,method='boot',nsim=500,boot.type='perc')

summary(PTm0 )$coef;PTm0CI 
summary(PTm1 )$coef;PTm1CI 
summary(PTm2 )$coef;PTm2CI 
summary(PTm3 )$coef;PTm3CI 
summary(PTm4 )$coef;PTm4CI 
summary(PTm5 )$coef;PTm5CI 
summary(PTm6 )$coef;PTm6CI 
summary(PTm7 )$coef;PTm7CI 
summary(PTm8 )$coef;PTm8CI 
summary(PTm9 )$coef;PTm9CI 
summary(PTm10)$coef;PTm10CI
summary(PTm11)$coef;PTm11CI
summary(PTm12)$coef;PTm12CI
summary(PWm0 )$coef;PWm0CI 
summary(PWm1 )$coef;PWm1CI 
summary(PWm2 )$coef;PWm2CI 
summary(PWm3 )$coef;PWm3CI 
summary(PWm4 )$coef;PWm4CI 
summary(PWm5 )$coef;PWm5CI 
summary(PWm6 )$coef;PWm6CI 
summary(PBm0 )$coef;PBm0CI 
summary(PBm1 )$coef;PBm1CI 
summary(PBm2 )$coef;PBm2CI 
summary(PBm3 )$coef;PBm3CI 
summary(PBm4 )$coef;PBm4CI 
summary(PBm5 )$coef;PBm5CI 
summary(PBm6 )$coef;PBm6CI 
summary(PHm0 )$coef;PHm0CI 
summary(PHm1 )$coef;PHm1CI 
summary(PHm2 )$coef;PHm2CI 
summary(PHm3 )$coef;PHm3CI 
summary(PHm4 )$coef;PHm4CI 
summary(PHm5 )$coef;PHm5CI 
summary(PHm6 )$coef;PHm6CI 






# Teen Birth
# Teen Birth
# Teen Birth
# Teen Birth
# Teen Birth

# Centering Variables
mean(TT$PopHP)     
mean(TT$FBornT)    
mean(TT$ICEArrR)   
mean(TT$ICEArrYCR) 
mean(TW$PopHP)     
mean(TW$FBornT)    
mean(TW$ICEArrR)   
mean(TW$ICEArrYCR) 
mean(TB$PopHP)     
mean(TB$FBornT)    
mean(TB$ICEArrR)   
mean(TB$ICEArrYCR) 
mean(TH$PopHP)     
mean(TH$FBornT)    
mean(TH$ICEArrR)   
mean(TH$ICEArrYCR) 
TT$PopHPc    <-TT$PopHP    -mean(TT$PopHP)
TT$FBornTc   <-TT$FBornT   -mean(TT$FBornT)
TT$ICEArrRc  <-TT$ICEArrR  -mean(TT$ICEArrR)
TT$ICEArrYCRc<-TT$ICEArrYCR-mean(TT$ICEArrYCR)
TW$PopHPc    <-TW$PopHP    -mean(TW$PopHP)
TW$FBornTc   <-TW$FBornT   -mean(TW$FBornT)
TW$ICEArrRc  <-TW$ICEArrR  -mean(TW$ICEArrR)
TW$ICEArrYCRc<-TW$ICEArrYCR-mean(TW$ICEArrYCR)
TB$PopHPc    <-TB$PopHP    -mean(TB$PopHP)
TB$FBornTc   <-TB$FBornT   -mean(TB$FBornT)
TB$ICEArrRc  <-TB$ICEArrR  -mean(TB$ICEArrR)
TB$ICEArrYCRc<-TB$ICEArrYCR-mean(TB$ICEArrYCR)
TH$PopHPc    <-TH$PopHP    -mean(TH$PopHP)
TH$FBornTc   <-TH$FBornT   -mean(TH$FBornT)
TH$ICEArrRc  <-TH$ICEArrR  -mean(TH$ICEArrR)
TH$ICEArrYCRc<-TH$ICEArrYCR-mean(TH$ICEArrYCR)

# Modeling
TTm0 <-lmer(TBTT1r~Year                                                                                           +(1|StateFIPS),data=TT)
TTm1 <-lmer(TBTT1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=TT)
TTm2 <-lmer(TBTT1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=TT)
TTm3 <-lmer(TBTT1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=TT)
TTm4 <-lmer(TBTT1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=TT)
TTm5 <-lmer(TBTT1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=TT)
TTm6 <-lmer(TBTT1r~Year*PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=TT)
TTm7 <-lmer(TBTT1r~Year*FBornTc+PopHPc+ICEArrYCRc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=TT)
TTm8 <-lmer(TBTT1r~Year*ICEArrYCRc+PopHPc+FBornTc+PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=TT)
TTm9 <-lmer(TBTT1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=TT)
TTm10<-lmer(TBTT1r~Year*PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=TT)
TTm11<-lmer(TBTT1r~Year*FBornTc+PopHPc+ICEArrRc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=TT)
TTm12<-lmer(TBTT1r~Year*ICEArrRc+PopHPc+FBornTc  +PopBP+ChildPT+MalePT+SingleT+NoHighT+CPovT+HValueT+MoveT+USDA_RUC+(1|StateFIPS),data=TT)
TWm0 <-lmer(TBTW1r~Year                                                                                           +(1|StateFIPS),data=TW)
TWm1 <-lmer(TBTW1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=TW)
TWm2 <-lmer(TBTW1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=TW)
TWm3 <-lmer(TBTW1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=TW)
TWm4 <-lmer(TBTW1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=TW)
TWm5 <-lmer(TBTW1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+MoveW+USDA_RUC+(1|StateFIPS),data=TW)
TWm6 <-lmer(TBTW1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPW+MalePW+SingleW+NoHighW+CPovW+HValueT+MoveW+USDA_RUC+(1|StateFIPS),data=TW)
TBm0 <-lmer(TBTB1r~Year                                                                                           +(1|StateFIPS),data=TB)
TBm1 <-lmer(TBTB1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=TB)
TBm2 <-lmer(TBTB1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=TB)
TBm3 <-lmer(TBTB1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=TB)
TBm4 <-lmer(TBTB1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=TB)
TBm5 <-lmer(TBTB1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+MoveB+USDA_RUC+(1|StateFIPS),data=TB)
TBm6 <-lmer(TBTB1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPB+MalePB+SingleB+NoHighB+CPovB+HValueT+MoveB+USDA_RUC+(1|StateFIPS),data=TB)
THm0 <-lmer(TBTH1r~Year                                                                                           +(1|StateFIPS),data=TH)
THm1 <-lmer(TBTH1r~Year+PopHPc                                                                                    +(1|StateFIPS),data=TH)
THm2 <-lmer(TBTH1r~Year+FBornTc                                                                                   +(1|StateFIPS),data=TH)
THm3 <-lmer(TBTH1r~Year+ICEArrRc                                                                                  +(1|StateFIPS),data=TH)
THm4 <-lmer(TBTH1r~Year+ICEArrYCRc                                                                                +(1|StateFIPS),data=TH)
THm5 <-lmer(TBTH1r~Year+PopHPc+FBornTc+ICEArrYCRc+PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+MoveH+USDA_RUC+(1|StateFIPS),data=TH)
THm6 <-lmer(TBTH1r~Year+PopHPc+FBornTc+ICEArrRc  +PopBP+ChildPH+MalePH+SingleH+NoHighH+CPovH+HValueT+MoveH+USDA_RUC+(1|StateFIPS),data=TH)

summary(TTm0 )
summary(TTm1 )
summary(TTm2 )
summary(TTm3 )
summary(TTm4 )
summary(TTm5 ) 
summary(TTm6 )
summary(TTm7 )
summary(TTm8 )
summary(TTm9 )
summary(TTm10)
summary(TTm11)
summary(TTm12)
summary(TWm0 )
summary(TWm1 )
summary(TWm2 )
summary(TWm3 )
summary(TWm4 )
summary(TWm5 ) 
summary(TWm6 )
summary(TBm0 )
summary(TBm1 )
summary(TBm2 )
summary(TBm3 )
summary(TBm4 )
summary(TBm5 ) 
summary(TBm6 )
summary(THm0 )
summary(THm1 )
summary(THm2 )
summary(THm3 )
summary(THm4 )
summary(THm5 ) 
summary(THm6 )

# Model Fit
AIC(
  TTm0 ,
  TTm1 ,
  TTm2 ,
  TTm3 ,
  TTm4 ,
  TTm5 ,
  TTm6 ,
  TTm7 ,
  TTm8 ,
  TTm9 ,
  TTm10,
  TTm11,
  TTm12)
AIC(
  TWm0,
  TWm1,
  TWm2,
  TWm3,
  TWm4,
  TWm5,
  TWm6)
AIC(
  TBm0,
  TBm1,
  TBm2,
  TBm3,
  TBm4,
  TBm5,
  TBm6)
AIC(
  THm0,
  THm1,
  THm2,
  THm3,
  THm4,
  THm5,
  THm6)

# Formal Test for Interaction
anova(TTm5,TTm6 )
anova(TTm5,TTm7 )
anova(TTm5,TTm8 )
anova(TTm9,TTm10)
anova(TTm9,TTm11)
anova(TTm9,TTm12)

# VIF
check_collinearity(TTm5 )
check_collinearity(TTm6 )
check_collinearity(TTm7 )
check_collinearity(TTm8 )
check_collinearity(TTm9 )
check_collinearity(TTm10)
check_collinearity(TTm11)
check_collinearity(TTm12)
check_collinearity(TWm5 )
check_collinearity(TWm6 )
check_collinearity(TBm5 )
check_collinearity(TBm6 )
check_collinearity(THm5 )
check_collinearity(THm6 )

# bootstrap confidence interval
TTm0CI <-confint(TTm0 ,method='boot',nsim=500,boot.type='perc')
TTm1CI <-confint(TTm1 ,method='boot',nsim=500,boot.type='perc')
TTm2CI <-confint(TTm2 ,method='boot',nsim=500,boot.type='perc')
TTm3CI <-confint(TTm3 ,method='boot',nsim=500,boot.type='perc')
TTm4CI <-confint(TTm4 ,method='boot',nsim=500,boot.type='perc')
TTm5CI <-confint(TTm5 ,method='boot',nsim=500,boot.type='perc')
TTm6CI <-confint(TTm6 ,method='boot',nsim=500,boot.type='perc')
TTm7CI <-confint(TTm7 ,method='boot',nsim=500,boot.type='perc')
TTm8CI <-confint(TTm8 ,method='boot',nsim=500,boot.type='perc')
TTm9CI <-confint(TTm9 ,method='boot',nsim=500,boot.type='perc')
TTm10CI<-confint(TTm10,method='boot',nsim=500,boot.type='perc')
TTm11CI<-confint(TTm11,method='boot',nsim=500,boot.type='perc')
TTm12CI<-confint(TTm12,method='boot',nsim=500,boot.type='perc')
TWm0CI <-confint(TWm0 ,method='boot',nsim=500,boot.type='perc')
TWm1CI <-confint(TWm1 ,method='boot',nsim=500,boot.type='perc')
TWm2CI <-confint(TWm2 ,method='boot',nsim=500,boot.type='perc')
TWm3CI <-confint(TWm3 ,method='boot',nsim=500,boot.type='perc')
TWm4CI <-confint(TWm4 ,method='boot',nsim=500,boot.type='perc')
TWm5CI <-confint(TWm5 ,method='boot',nsim=500,boot.type='perc')
TWm6CI <-confint(TWm6 ,method='boot',nsim=500,boot.type='perc')
TBm0CI <-confint(TBm0 ,method='boot',nsim=500,boot.type='perc')
TBm1CI <-confint(TBm1 ,method='boot',nsim=500,boot.type='perc')
TBm2CI <-confint(TBm2 ,method='boot',nsim=500,boot.type='perc')
TBm3CI <-confint(TBm3 ,method='boot',nsim=500,boot.type='perc')
TBm4CI <-confint(TBm4 ,method='boot',nsim=500,boot.type='perc')
TBm5CI <-confint(TBm5 ,method='boot',nsim=500,boot.type='perc')
TBm6CI <-confint(TBm6 ,method='boot',nsim=500,boot.type='perc')
THm0CI <-confint(THm0 ,method='boot',nsim=500,boot.type='perc')
THm1CI <-confint(THm1 ,method='boot',nsim=500,boot.type='perc')
THm2CI <-confint(THm2 ,method='boot',nsim=500,boot.type='perc')
THm3CI <-confint(THm3 ,method='boot',nsim=500,boot.type='perc')
THm4CI <-confint(THm4 ,method='boot',nsim=500,boot.type='perc')
THm5CI <-confint(THm5 ,method='boot',nsim=500,boot.type='perc')
THm6CI <-confint(THm6 ,method='boot',nsim=500,boot.type='perc')

summary(TTm0 )$coef;TTm0CI 
summary(TTm1 )$coef;TTm1CI 
summary(TTm2 )$coef;TTm2CI 
summary(TTm3 )$coef;TTm3CI 
summary(TTm4 )$coef;TTm4CI 
summary(TTm5 )$coef;TTm5CI 
summary(TTm6 )$coef;TTm6CI 
summary(TTm7 )$coef;TTm7CI 
summary(TTm8 )$coef;TTm8CI 
summary(TTm9 )$coef;TTm9CI 
summary(TTm10)$coef;TTm10CI
summary(TTm11)$coef;TTm11CI
summary(TTm12)$coef;TTm12CI
summary(TWm0 )$coef;TWm0CI 
summary(TWm1 )$coef;TWm1CI 
summary(TWm2 )$coef;TWm2CI 
summary(TWm3 )$coef;TWm3CI 
summary(TWm4 )$coef;TWm4CI 
summary(TWm5 )$coef;TWm5CI 
summary(TWm6 )$coef;TWm6CI 
summary(TBm0 )$coef;TBm0CI 
summary(TBm1 )$coef;TBm1CI 
summary(TBm2 )$coef;TBm2CI 
summary(TBm3 )$coef;TBm3CI 
summary(TBm4 )$coef;TBm4CI 
summary(TBm5 )$coef;TBm5CI 
summary(TBm6 )$coef;TBm6CI 
summary(THm0 )$coef;THm0CI 
summary(THm1 )$coef;THm1CI 
summary(THm2 )$coef;THm2CI 
summary(THm3 )$coef;THm3CI 
summary(THm4 )$coef;THm4CI 
summary(THm5 )$coef;THm5CI 
summary(THm6 )$coef;THm6CI 



# Tables
# Tables
# Tables
# Tables
# Tables
# Tables
# Tables
# Tables
# Tables
# Tables
# Tables
# Tables

mean(CT$RptTr)








